@@ -30,9 +30,9 @@ NTSTATUS dcerpc_dfs_Add_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem_ctx,
 struct tevent_req *dcerpc_dfs_Add_send(TALLOC_CTX *mem_ctx,
 				       struct tevent_context *ev,
 				       struct dcerpc_binding_handle *h,
-				       const char *_path /* [in] [charset(UTF16),ref] */,
+				       const char *_path /* [in] [ref,charset(UTF16)] */,
 				       const char *_server /* [in] [charset(UTF16),ref] */,
-				       const char *_share /* [in] [unique,charset(UTF16)] */,
+				       const char *_share /* [in] [charset(UTF16),unique] */,
 				       const char *_comment /* [in] [unique,charset(UTF16)] */,
 				       uint32_t _flags /* [in]  */);
 NTSTATUS dcerpc_dfs_Add_recv(struct tevent_req *req,
@@ -40,9 +40,9 @@ NTSTATUS dcerpc_dfs_Add_recv(struct tevent_req *req,
 			     WERROR *result);
 NTSTATUS dcerpc_dfs_Add(struct dcerpc_binding_handle *h,
 			TALLOC_CTX *mem_ctx,
-			const char *_path /* [in] [charset(UTF16),ref] */,
+			const char *_path /* [in] [ref,charset(UTF16)] */,
 			const char *_server /* [in] [charset(UTF16),ref] */,
-			const char *_share /* [in] [unique,charset(UTF16)] */,
+			const char *_share /* [in] [charset(UTF16),unique] */,
 			const char *_comment /* [in] [unique,charset(UTF16)] */,
 			uint32_t _flags /* [in]  */,
 			WERROR *result);
@@ -56,16 +56,16 @@ NTSTATUS dcerpc_dfs_Remove_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem_ct
 struct tevent_req *dcerpc_dfs_Remove_send(TALLOC_CTX *mem_ctx,
 					  struct tevent_context *ev,
 					  struct dcerpc_binding_handle *h,
-					  const char *_dfs_entry_path /* [in] [ref,charset(UTF16)] */,
-					  const char *_servername /* [in] [unique,charset(UTF16)] */,
+					  const char *_dfs_entry_path /* [in] [charset(UTF16),ref] */,
+					  const char *_servername /* [in] [charset(UTF16),unique] */,
 					  const char *_sharename /* [in] [charset(UTF16),unique] */);
 NTSTATUS dcerpc_dfs_Remove_recv(struct tevent_req *req,
 				TALLOC_CTX *mem_ctx,
 				WERROR *result);
 NTSTATUS dcerpc_dfs_Remove(struct dcerpc_binding_handle *h,
 			   TALLOC_CTX *mem_ctx,
-			   const char *_dfs_entry_path /* [in] [ref,charset(UTF16)] */,
-			   const char *_servername /* [in] [unique,charset(UTF16)] */,
+			   const char *_dfs_entry_path /* [in] [charset(UTF16),ref] */,
+			   const char *_servername /* [in] [charset(UTF16),unique] */,
 			   const char *_sharename /* [in] [charset(UTF16),unique] */,
 			   WERROR *result);
 
@@ -79,20 +79,20 @@ struct tevent_req *dcerpc_dfs_SetInfo_send(TALLOC_CTX *mem_ctx,
 					   struct tevent_context *ev,
 					   struct dcerpc_binding_handle *h,
 					   const char *_dfs_entry_path /* [in] [charset(UTF16)] */,
-					   const char *_servername /* [in] [unique,charset(UTF16)] */,
+					   const char *_servername /* [in] [charset(UTF16),unique] */,
 					   const char *_sharename /* [in] [charset(UTF16),unique] */,
 					   uint32_t _level /* [in]  */,
-					   union dfs_Info *_info /* [in] [switch_is(level),ref] */);
+					   union dfs_Info *_info /* [in] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_dfs_SetInfo_recv(struct tevent_req *req,
 				 TALLOC_CTX *mem_ctx,
 				 WERROR *result);
 NTSTATUS dcerpc_dfs_SetInfo(struct dcerpc_binding_handle *h,
 			    TALLOC_CTX *mem_ctx,
 			    const char *_dfs_entry_path /* [in] [charset(UTF16)] */,
-			    const char *_servername /* [in] [unique,charset(UTF16)] */,
+			    const char *_servername /* [in] [charset(UTF16),unique] */,
 			    const char *_sharename /* [in] [charset(UTF16),unique] */,
 			    uint32_t _level /* [in]  */,
-			    union dfs_Info *_info /* [in] [switch_is(level),ref] */,
+			    union dfs_Info *_info /* [in] [ref,switch_is(level)] */,
 			    WERROR *result);
 
 struct tevent_req *dcerpc_dfs_GetInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -106,9 +106,9 @@ struct tevent_req *dcerpc_dfs_GetInfo_send(TALLOC_CTX *mem_ctx,
 					   struct dcerpc_binding_handle *h,
 					   const char *_dfs_entry_path /* [in] [charset(UTF16)] */,
 					   const char *_servername /* [in] [unique,charset(UTF16)] */,
-					   const char *_sharename /* [in] [unique,charset(UTF16)] */,
+					   const char *_sharename /* [in] [charset(UTF16),unique] */,
 					   uint32_t _level /* [in]  */,
-					   union dfs_Info *_info /* [out] [switch_is(level),ref] */);
+					   union dfs_Info *_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_dfs_GetInfo_recv(struct tevent_req *req,
 				 TALLOC_CTX *mem_ctx,
 				 WERROR *result);
@@ -116,9 +116,9 @@ NTSTATUS dcerpc_dfs_GetInfo(struct dcerpc_binding_handle *h,
 			    TALLOC_CTX *mem_ctx,
 			    const char *_dfs_entry_path /* [in] [charset(UTF16)] */,
 			    const char *_servername /* [in] [unique,charset(UTF16)] */,
-			    const char *_sharename /* [in] [unique,charset(UTF16)] */,
+			    const char *_sharename /* [in] [charset(UTF16),unique] */,
 			    uint32_t _level /* [in]  */,
-			    union dfs_Info *_info /* [out] [switch_is(level),ref] */,
+			    union dfs_Info *_info /* [out] [ref,switch_is(level)] */,
 			    WERROR *result);
 
 struct tevent_req *dcerpc_dfs_Enum_r_send(TALLOC_CTX *mem_ctx,
@@ -307,7 +307,7 @@ struct tevent_req *dcerpc_dfs_GetDcAddress_send(TALLOC_CTX *mem_ctx,
 						struct tevent_context *ev,
 						struct dcerpc_binding_handle *h,
 						const char *_servername /* [in] [charset(UTF16)] */,
-						const char **_server_fullname /* [in,out] [charset(UTF16),ref] */,
+						const char **_server_fullname /* [in,out] [ref,charset(UTF16)] */,
 						uint8_t *_is_root /* [in,out] [ref] */,
 						uint32_t *_ttl /* [in,out] [ref] */);
 NTSTATUS dcerpc_dfs_GetDcAddress_recv(struct tevent_req *req,
@@ -316,7 +316,7 @@ NTSTATUS dcerpc_dfs_GetDcAddress_recv(struct tevent_req *req,
 NTSTATUS dcerpc_dfs_GetDcAddress(struct dcerpc_binding_handle *h,
 				 TALLOC_CTX *mem_ctx,
 				 const char *_servername /* [in] [charset(UTF16)] */,
-				 const char **_server_fullname /* [in,out] [charset(UTF16),ref] */,
+				 const char **_server_fullname /* [in,out] [ref,charset(UTF16)] */,
 				 uint8_t *_is_root /* [in,out] [ref] */,
 				 uint32_t *_ttl /* [in,out] [ref] */,
 				 WERROR *result);
