@@ -56,7 +56,7 @@ struct tevent_req *dcerpc_drsuapi_DsReplicaSync_send(TALLOC_CTX *mem_ctx,
 						     struct dcerpc_binding_handle *h,
 						     struct policy_handle *_bind_handle /* [in] [ref] */,
 						     uint32_t _level /* [in]  */,
-						     union drsuapi_DsReplicaSyncRequest *_req /* [in] [ref,switch_is(level)] */);
+						     union drsuapi_DsReplicaSyncRequest *_req /* [in] [switch_is(level),ref] */);
 NTSTATUS dcerpc_drsuapi_DsReplicaSync_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
 					   WERROR *result);
@@ -64,7 +64,7 @@ NTSTATUS dcerpc_drsuapi_DsReplicaSync(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      struct policy_handle *_bind_handle /* [in] [ref] */,
 				      uint32_t _level /* [in]  */,
-				      union drsuapi_DsReplicaSyncRequest *_req /* [in] [ref,switch_is(level)] */,
+				      union drsuapi_DsReplicaSyncRequest *_req /* [in] [switch_is(level),ref] */,
 				      WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsGetNCChanges_r_send(TALLOC_CTX *mem_ctx,
@@ -78,9 +78,9 @@ struct tevent_req *dcerpc_drsuapi_DsGetNCChanges_send(TALLOC_CTX *mem_ctx,
 						      struct dcerpc_binding_handle *h,
 						      struct policy_handle *_bind_handle /* [in] [ref] */,
 						      uint32_t _level /* [in]  */,
-						      union drsuapi_DsGetNCChangesRequest *_req /* [in] [ref,switch_is(level)] */,
+						      union drsuapi_DsGetNCChangesRequest *_req /* [in] [switch_is(level),ref] */,
 						      uint32_t *_level_out /* [out] [ref] */,
-						      union drsuapi_DsGetNCChangesCtr *_ctr /* [out] [ref,switch_is(*level_out)] */);
+						      union drsuapi_DsGetNCChangesCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
 NTSTATUS dcerpc_drsuapi_DsGetNCChanges_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    WERROR *result);
@@ -88,9 +88,9 @@ NTSTATUS dcerpc_drsuapi_DsGetNCChanges(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
 				       struct policy_handle *_bind_handle /* [in] [ref] */,
 				       uint32_t _level /* [in]  */,
-				       union drsuapi_DsGetNCChangesRequest *_req /* [in] [ref,switch_is(level)] */,
+				       union drsuapi_DsGetNCChangesRequest *_req /* [in] [switch_is(level),ref] */,
 				       uint32_t *_level_out /* [out] [ref] */,
-				       union drsuapi_DsGetNCChangesCtr *_ctr /* [out] [ref,switch_is(*level_out)] */,
+				       union drsuapi_DsGetNCChangesCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
 				       WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsReplicaUpdateRefs_r_send(TALLOC_CTX *mem_ctx,
@@ -244,7 +244,7 @@ struct tevent_req *dcerpc_drsuapi_DsCrackNames_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    struct policy_handle *_bind_handle /* [in] [ref] */,
 						    uint32_t _level /* [in]  */,
-						    union drsuapi_DsNameRequest *_req /* [in] [ref,switch_is(level)] */,
+						    union drsuapi_DsNameRequest *_req /* [in] [switch_is(level),ref] */,
 						    uint32_t *_level_out /* [out] [ref] */,
 						    union drsuapi_DsNameCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
 NTSTATUS dcerpc_drsuapi_DsCrackNames_recv(struct tevent_req *req,
@@ -254,7 +254,7 @@ NTSTATUS dcerpc_drsuapi_DsCrackNames(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     struct policy_handle *_bind_handle /* [in] [ref] */,
 				     uint32_t _level /* [in]  */,
-				     union drsuapi_DsNameRequest *_req /* [in] [ref,switch_is(level)] */,
+				     union drsuapi_DsNameRequest *_req /* [in] [switch_is(level),ref] */,
 				     uint32_t *_level_out /* [out] [ref] */,
 				     union drsuapi_DsNameCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
 				     WERROR *result);
@@ -270,9 +270,9 @@ struct tevent_req *dcerpc_drsuapi_DsWriteAccountSpn_send(TALLOC_CTX *mem_ctx,
 							 struct dcerpc_binding_handle *h,
 							 struct policy_handle *_bind_handle /* [in] [ref] */,
 							 uint32_t _level /* [in]  */,
-							 union drsuapi_DsWriteAccountSpnRequest *_req /* [in] [ref,switch_is(level)] */,
+							 union drsuapi_DsWriteAccountSpnRequest *_req /* [in] [switch_is(level),ref] */,
 							 uint32_t *_level_out /* [out] [ref] */,
-							 union drsuapi_DsWriteAccountSpnResult *_res /* [out] [ref,switch_is(*level_out)] */);
+							 union drsuapi_DsWriteAccountSpnResult *_res /* [out] [switch_is(*level_out),ref] */);
 NTSTATUS dcerpc_drsuapi_DsWriteAccountSpn_recv(struct tevent_req *req,
 					       TALLOC_CTX *mem_ctx,
 					       WERROR *result);
@@ -280,9 +280,9 @@ NTSTATUS dcerpc_drsuapi_DsWriteAccountSpn(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
 					  struct policy_handle *_bind_handle /* [in] [ref] */,
 					  uint32_t _level /* [in]  */,
-					  union drsuapi_DsWriteAccountSpnRequest *_req /* [in] [ref,switch_is(level)] */,
+					  union drsuapi_DsWriteAccountSpnRequest *_req /* [in] [switch_is(level),ref] */,
 					  uint32_t *_level_out /* [out] [ref] */,
-					  union drsuapi_DsWriteAccountSpnResult *_res /* [out] [ref,switch_is(*level_out)] */,
+					  union drsuapi_DsWriteAccountSpnResult *_res /* [out] [switch_is(*level_out),ref] */,
 					  WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsRemoveDSServer_r_send(TALLOC_CTX *mem_ctx,
@@ -298,7 +298,7 @@ struct tevent_req *dcerpc_drsuapi_DsRemoveDSServer_send(TALLOC_CTX *mem_ctx,
 							uint32_t _level /* [in]  */,
 							union drsuapi_DsRemoveDSServerRequest *_req /* [in] [ref,switch_is(level)] */,
 							uint32_t *_level_out /* [out] [ref] */,
-							union drsuapi_DsRemoveDSServerResult *_res /* [out] [switch_is(*level_out),ref] */);
+							union drsuapi_DsRemoveDSServerResult *_res /* [out] [ref,switch_is(*level_out)] */);
 NTSTATUS dcerpc_drsuapi_DsRemoveDSServer_recv(struct tevent_req *req,
 					      TALLOC_CTX *mem_ctx,
 					      WERROR *result);
@@ -308,7 +308,7 @@ NTSTATUS dcerpc_drsuapi_DsRemoveDSServer(struct dcerpc_binding_handle *h,
 					 uint32_t _level /* [in]  */,
 					 union drsuapi_DsRemoveDSServerRequest *_req /* [in] [ref,switch_is(level)] */,
 					 uint32_t *_level_out /* [out] [ref] */,
-					 union drsuapi_DsRemoveDSServerResult *_res /* [out] [switch_is(*level_out),ref] */,
+					 union drsuapi_DsRemoveDSServerResult *_res /* [out] [ref,switch_is(*level_out)] */,
 					 WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsGetDomainControllerInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -322,9 +322,9 @@ struct tevent_req *dcerpc_drsuapi_DsGetDomainControllerInfo_send(TALLOC_CTX *mem
 								 struct dcerpc_binding_handle *h,
 								 struct policy_handle *_bind_handle /* [in] [ref] */,
 								 int32_t _level /* [in]  */,
-								 union drsuapi_DsGetDCInfoRequest *_req /* [in] [ref,switch_is(level)] */,
+								 union drsuapi_DsGetDCInfoRequest *_req /* [in] [switch_is(level),ref] */,
 								 int32_t *_level_out /* [out] [ref] */,
-								 union drsuapi_DsGetDCInfoCtr *_ctr /* [out] [ref,switch_is(*level_out)] */);
+								 union drsuapi_DsGetDCInfoCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
 NTSTATUS dcerpc_drsuapi_DsGetDomainControllerInfo_recv(struct tevent_req *req,
 						       TALLOC_CTX *mem_ctx,
 						       WERROR *result);
@@ -332,9 +332,9 @@ NTSTATUS dcerpc_drsuapi_DsGetDomainControllerInfo(struct dcerpc_binding_handle *
 						  TALLOC_CTX *mem_ctx,
 						  struct policy_handle *_bind_handle /* [in] [ref] */,
 						  int32_t _level /* [in]  */,
-						  union drsuapi_DsGetDCInfoRequest *_req /* [in] [ref,switch_is(level)] */,
+						  union drsuapi_DsGetDCInfoRequest *_req /* [in] [switch_is(level),ref] */,
 						  int32_t *_level_out /* [out] [ref] */,
-						  union drsuapi_DsGetDCInfoCtr *_ctr /* [out] [ref,switch_is(*level_out)] */,
+						  union drsuapi_DsGetDCInfoCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
 						  WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsAddEntry_r_send(TALLOC_CTX *mem_ctx,
@@ -348,7 +348,7 @@ struct tevent_req *dcerpc_drsuapi_DsAddEntry_send(TALLOC_CTX *mem_ctx,
 						  struct dcerpc_binding_handle *h,
 						  struct policy_handle *_bind_handle /* [in] [ref] */,
 						  uint32_t _level /* [in]  */,
-						  union drsuapi_DsAddEntryRequest *_req /* [in] [switch_is(level),ref] */,
+						  union drsuapi_DsAddEntryRequest *_req /* [in] [ref,switch_is(level)] */,
 						  uint32_t *_level_out /* [out] [ref] */,
 						  union drsuapi_DsAddEntryCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
 NTSTATUS dcerpc_drsuapi_DsAddEntry_recv(struct tevent_req *req,
@@ -358,7 +358,7 @@ NTSTATUS dcerpc_drsuapi_DsAddEntry(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
 				   struct policy_handle *_bind_handle /* [in] [ref] */,
 				   uint32_t _level /* [in]  */,
-				   union drsuapi_DsAddEntryRequest *_req /* [in] [switch_is(level),ref] */,
+				   union drsuapi_DsAddEntryRequest *_req /* [in] [ref,switch_is(level)] */,
 				   uint32_t *_level_out /* [out] [ref] */,
 				   union drsuapi_DsAddEntryCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
 				   WERROR *result);
@@ -374,7 +374,7 @@ struct tevent_req *dcerpc_drsuapi_DsExecuteKCC_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    struct policy_handle *_bind_handle /* [in] [ref] */,
 						    uint32_t _level /* [in]  */,
-						    union drsuapi_DsExecuteKCCRequest *_req /* [in] [switch_is(level),ref] */);
+						    union drsuapi_DsExecuteKCCRequest *_req /* [in] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_drsuapi_DsExecuteKCC_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
 					  WERROR *result);
@@ -382,7 +382,7 @@ NTSTATUS dcerpc_drsuapi_DsExecuteKCC(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     struct policy_handle *_bind_handle /* [in] [ref] */,
 				     uint32_t _level /* [in]  */,
-				     union drsuapi_DsExecuteKCCRequest *_req /* [in] [switch_is(level),ref] */,
+				     union drsuapi_DsExecuteKCCRequest *_req /* [in] [ref,switch_is(level)] */,
 				     WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsReplicaGetInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -398,7 +398,7 @@ struct tevent_req *dcerpc_drsuapi_DsReplicaGetInfo_send(TALLOC_CTX *mem_ctx,
 							enum drsuapi_DsReplicaGetInfoLevel _level /* [in]  */,
 							union drsuapi_DsReplicaGetInfoRequest *_req /* [in] [ref,switch_is(level)] */,
 							enum drsuapi_DsReplicaInfoType *_info_type /* [out] [ref] */,
-							union drsuapi_DsReplicaInfo *_info /* [out] [switch_is(*info_type),ref] */);
+							union drsuapi_DsReplicaInfo *_info /* [out] [ref,switch_is(*info_type)] */);
 NTSTATUS dcerpc_drsuapi_DsReplicaGetInfo_recv(struct tevent_req *req,
 					      TALLOC_CTX *mem_ctx,
 					      WERROR *result);
@@ -408,7 +408,7 @@ NTSTATUS dcerpc_drsuapi_DsReplicaGetInfo(struct dcerpc_binding_handle *h,
 					 enum drsuapi_DsReplicaGetInfoLevel _level /* [in]  */,
 					 union drsuapi_DsReplicaGetInfoRequest *_req /* [in] [ref,switch_is(level)] */,
 					 enum drsuapi_DsReplicaInfoType *_info_type /* [out] [ref] */,
-					 union drsuapi_DsReplicaInfo *_info /* [out] [switch_is(*info_type),ref] */,
+					 union drsuapi_DsReplicaInfo *_info /* [out] [ref,switch_is(*info_type)] */,
 					 WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsGetMemberships2_r_send(TALLOC_CTX *mem_ctx,
@@ -422,7 +422,7 @@ struct tevent_req *dcerpc_drsuapi_DsGetMemberships2_send(TALLOC_CTX *mem_ctx,
 							 struct dcerpc_binding_handle *h,
 							 struct policy_handle *_bind_handle /* [in] [ref] */,
 							 uint32_t _level /* [in]  */,
-							 union drsuapi_DsGetMemberships2Request *_req /* [in] [switch_is(level),ref] */,
+							 union drsuapi_DsGetMemberships2Request *_req /* [in] [ref,switch_is(level)] */,
 							 uint32_t *_level_out /* [out] [ref] */,
 							 union drsuapi_DsGetMemberships2Ctr *_ctr /* [out] [ref,switch_is(*level_out)] */);
 NTSTATUS dcerpc_drsuapi_DsGetMemberships2_recv(struct tevent_req *req,
@@ -432,7 +432,7 @@ NTSTATUS dcerpc_drsuapi_DsGetMemberships2(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
 					  struct policy_handle *_bind_handle /* [in] [ref] */,
 					  uint32_t _level /* [in]  */,
-					  union drsuapi_DsGetMemberships2Request *_req /* [in] [switch_is(level),ref] */,
+					  union drsuapi_DsGetMemberships2Request *_req /* [in] [ref,switch_is(level)] */,
 					  uint32_t *_level_out /* [out] [ref] */,
 					  union drsuapi_DsGetMemberships2Ctr *_ctr /* [out] [ref,switch_is(*level_out)] */,
 					  WERROR *result);
