@@ -88,8 +88,8 @@ struct tevent_req *dcerpc_frstrans_RequestUpdates_send(TALLOC_CTX *mem_ctx,
 						       uint32_t _hash_requested /* [in] [range(0,1)] */,
 						       enum frstrans_UpdateRequestType _update_request_type /* [in] [range(0,2)] */,
 						       uint32_t _version_vector_diff_count /* [in]  */,
-						       struct frstrans_VersionVector *_version_vector_diff /* [in] [ref,size_is(version_vector_diff_count)] */,
-						       struct frstrans_Update *_frs_update /* [out] [length_is(*update_count),size_is(credits_available),ref] */,
+						       struct frstrans_VersionVector *_version_vector_diff /* [in] [size_is(version_vector_diff_count),ref] */,
+						       struct frstrans_Update *_frs_update /* [out] [length_is(*update_count),ref,size_is(credits_available)] */,
 						       uint32_t *_update_count /* [out] [ref] */,
 						       enum frstrans_UpdateStatus *_update_status /* [out] [ref] */,
 						       struct GUID *_gvsn_db_guid /* [out] [ref] */,
@@ -105,8 +105,8 @@ NTSTATUS dcerpc_frstrans_RequestUpdates(struct dcerpc_binding_handle *h,
 					uint32_t _hash_requested /* [in] [range(0,1)] */,
 					enum frstrans_UpdateRequestType _update_request_type /* [in] [range(0,2)] */,
 					uint32_t _version_vector_diff_count /* [in]  */,
-					struct frstrans_VersionVector *_version_vector_diff /* [in] [ref,size_is(version_vector_diff_count)] */,
-					struct frstrans_Update *_frs_update /* [out] [length_is(*update_count),size_is(credits_available),ref] */,
+					struct frstrans_VersionVector *_version_vector_diff /* [in] [size_is(version_vector_diff_count),ref] */,
+					struct frstrans_Update *_frs_update /* [out] [length_is(*update_count),ref,size_is(credits_available)] */,
 					uint32_t *_update_count /* [out] [ref] */,
 					enum frstrans_UpdateStatus *_update_status /* [out] [ref] */,
 					struct GUID *_gvsn_db_guid /* [out] [ref] */,
