@@ -53,7 +53,7 @@ struct tevent_req *dcerpc_PNP_GetDeviceList_send(TALLOC_CTX *mem_ctx,
 						 struct tevent_context *ev,
 						 struct dcerpc_binding_handle *h,
 						 const char *_filter /* [in] [charset(UTF16),unique] */,
-						 uint16_t *_buffer /* [out] [ref,size_is(*length),length_is(*length)] */,
+						 uint16_t *_buffer /* [out] [size_is(*length),ref,length_is(*length)] */,
 						 uint32_t *_length /* [in,out] [ref] */,
 						 uint32_t _flags /* [in]  */);
 NTSTATUS dcerpc_PNP_GetDeviceList_recv(struct tevent_req *req,
@@ -62,7 +62,7 @@ NTSTATUS dcerpc_PNP_GetDeviceList_recv(struct tevent_req *req,
 NTSTATUS dcerpc_PNP_GetDeviceList(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  const char *_filter /* [in] [charset(UTF16),unique] */,
-				  uint16_t *_buffer /* [out] [ref,size_is(*length),length_is(*length)] */,
+				  uint16_t *_buffer /* [out] [size_is(*length),ref,length_is(*length)] */,
 				  uint32_t *_length /* [in,out] [ref] */,
 				  uint32_t _flags /* [in]  */,
 				  WERROR *result);
@@ -133,7 +133,7 @@ struct tevent_req *dcerpc_PNP_HwProfFlags_send(TALLOC_CTX *mem_ctx,
 					       uint32_t _config /* [in]  */,
 					       uint32_t *_profile_flags /* [in,out] [ref] */,
 					       uint16_t *_veto_type /* [in,out] [unique] */,
-					       const char *_unknown5 /* [in] [charset(UTF16),unique] */,
+					       const char *_unknown5 /* [in] [unique,charset(UTF16)] */,
 					       const char **_unknown5a /* [out] [unique,charset(UTF16)] */,
 					       uint32_t _name_length /* [in]  */,
 					       uint32_t _flags /* [in]  */);
@@ -147,7 +147,7 @@ NTSTATUS dcerpc_PNP_HwProfFlags(struct dcerpc_binding_handle *h,
 				uint32_t _config /* [in]  */,
 				uint32_t *_profile_flags /* [in,out] [ref] */,
 				uint16_t *_veto_type /* [in,out] [unique] */,
-				const char *_unknown5 /* [in] [charset(UTF16),unique] */,
+				const char *_unknown5 /* [in] [unique,charset(UTF16)] */,
 				const char **_unknown5a /* [out] [unique,charset(UTF16)] */,
 				uint32_t _name_length /* [in]  */,
 				uint32_t _flags /* [in]  */,
