@@ -17,12 +17,12 @@ struct tevent_req *dcerpc_RemoteActivation_send(TALLOC_CTX *mem_ctx,
 						struct ORPCTHIS _this_object /* [in]  */,
 						struct ORPCTHAT *_that /* [out] [ref] */,
 						struct GUID _Clsid /* [in]  */,
-						const char *_pwszObjectName /* [in] [charset(UTF16),ref] */,
+						const char *_pwszObjectName /* [in] [ref,charset(UTF16)] */,
 						struct MInterfacePointer *_pObjectStorage /* [in] [ref] */,
 						uint32_t _ClientImpLevel /* [in]  */,
 						uint32_t _Mode /* [in]  */,
 						uint32_t _Interfaces /* [in] [range(1,32768)] */,
-						struct GUID *_pIIDs /* [in] [ref,size_is(Interfaces)] */,
+						struct GUID *_pIIDs /* [in] [size_is(Interfaces),ref] */,
 						uint16_t _num_protseqs /* [in]  */,
 						uint16_t *_protseq /* [in] [size_is(num_protseqs)] */,
 						uint64_t *_pOxid /* [out] [ref] */,
@@ -41,12 +41,12 @@ NTSTATUS dcerpc_RemoteActivation(struct dcerpc_binding_handle *h,
 				 struct ORPCTHIS _this_object /* [in]  */,
 				 struct ORPCTHAT *_that /* [out] [ref] */,
 				 struct GUID _Clsid /* [in]  */,
-				 const char *_pwszObjectName /* [in] [charset(UTF16),ref] */,
+				 const char *_pwszObjectName /* [in] [ref,charset(UTF16)] */,
 				 struct MInterfacePointer *_pObjectStorage /* [in] [ref] */,
 				 uint32_t _ClientImpLevel /* [in]  */,
 				 uint32_t _Mode /* [in]  */,
 				 uint32_t _Interfaces /* [in] [range(1,32768)] */,
-				 struct GUID *_pIIDs /* [in] [ref,size_is(Interfaces)] */,
+				 struct GUID *_pIIDs /* [in] [size_is(Interfaces),ref] */,
 				 uint16_t _num_protseqs /* [in]  */,
 				 uint16_t *_protseq /* [in] [size_is(num_protseqs)] */,
 				 uint64_t *_pOxid /* [out] [ref] */,
