@@ -190,7 +190,7 @@ struct tevent_req *dcerpc_samr_QueryDomainInfo_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    struct policy_handle *_domain_handle /* [in] [ref] */,
 						    enum samr_DomainInfoClass _level /* [in]  */,
-						    union samr_DomainInfo **_info /* [out] [ref,switch_is(level)] */);
+						    union samr_DomainInfo **_info /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_QueryDomainInfo_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
 					  NTSTATUS *result);
@@ -198,7 +198,7 @@ NTSTATUS dcerpc_samr_QueryDomainInfo(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     struct policy_handle *_domain_handle /* [in] [ref] */,
 				     enum samr_DomainInfoClass _level /* [in]  */,
-				     union samr_DomainInfo **_info /* [out] [ref,switch_is(level)] */,
+				     union samr_DomainInfo **_info /* [out] [switch_is(level),ref] */,
 				     NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_SetDomainInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -512,7 +512,7 @@ struct tevent_req *dcerpc_samr_SetGroupInfo_send(TALLOC_CTX *mem_ctx,
 						 struct dcerpc_binding_handle *h,
 						 struct policy_handle *_group_handle /* [in] [ref] */,
 						 enum samr_GroupInfoEnum _level /* [in]  */,
-						 union samr_GroupInfo *_info /* [in] [ref,switch_is(level)] */);
+						 union samr_GroupInfo *_info /* [in] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_SetGroupInfo_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
 				       NTSTATUS *result);
@@ -520,7 +520,7 @@ NTSTATUS dcerpc_samr_SetGroupInfo(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  struct policy_handle *_group_handle /* [in] [ref] */,
 				  enum samr_GroupInfoEnum _level /* [in]  */,
-				  union samr_GroupInfo *_info /* [in] [ref,switch_is(level)] */,
+				  union samr_GroupInfo *_info /* [in] [switch_is(level),ref] */,
 				  NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_AddGroupMember_r_send(TALLOC_CTX *mem_ctx,
@@ -824,7 +824,7 @@ struct tevent_req *dcerpc_samr_QueryUserInfo_send(TALLOC_CTX *mem_ctx,
 						  struct dcerpc_binding_handle *h,
 						  struct policy_handle *_user_handle /* [in] [ref] */,
 						  enum samr_UserInfoLevel _level /* [in]  */,
-						  union samr_UserInfo **_info /* [out] [switch_is(level),ref] */);
+						  union samr_UserInfo **_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_samr_QueryUserInfo_recv(struct tevent_req *req,
 					TALLOC_CTX *mem_ctx,
 					NTSTATUS *result);
@@ -832,7 +832,7 @@ NTSTATUS dcerpc_samr_QueryUserInfo(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
 				   struct policy_handle *_user_handle /* [in] [ref] */,
 				   enum samr_UserInfoLevel _level /* [in]  */,
-				   union samr_UserInfo **_info /* [out] [switch_is(level),ref] */,
+				   union samr_UserInfo **_info /* [out] [ref,switch_is(level)] */,
 				   NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_SetUserInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -846,7 +846,7 @@ struct tevent_req *dcerpc_samr_SetUserInfo_send(TALLOC_CTX *mem_ctx,
 						struct dcerpc_binding_handle *h,
 						struct policy_handle *_user_handle /* [in] [ref] */,
 						enum samr_UserInfoLevel _level /* [in]  */,
-						union samr_UserInfo *_info /* [in] [switch_is(level),ref] */);
+						union samr_UserInfo *_info /* [in] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_samr_SetUserInfo_recv(struct tevent_req *req,
 				      TALLOC_CTX *mem_ctx,
 				      NTSTATUS *result);
@@ -854,7 +854,7 @@ NTSTATUS dcerpc_samr_SetUserInfo(struct dcerpc_binding_handle *h,
 				 TALLOC_CTX *mem_ctx,
 				 struct policy_handle *_user_handle /* [in] [ref] */,
 				 enum samr_UserInfoLevel _level /* [in]  */,
-				 union samr_UserInfo *_info /* [in] [switch_is(level),ref] */,
+				 union samr_UserInfo *_info /* [in] [ref,switch_is(level)] */,
 				 NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_ChangePasswordUser_r_send(TALLOC_CTX *mem_ctx,
@@ -1058,7 +1058,7 @@ struct tevent_req *dcerpc_samr_QueryDomainInfo2_send(TALLOC_CTX *mem_ctx,
 						     struct dcerpc_binding_handle *h,
 						     struct policy_handle *_domain_handle /* [in] [ref] */,
 						     enum samr_DomainInfoClass _level /* [in]  */,
-						     union samr_DomainInfo **_info /* [out] [switch_is(level),ref] */);
+						     union samr_DomainInfo **_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_samr_QueryDomainInfo2_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
 					   NTSTATUS *result);
@@ -1066,7 +1066,7 @@ NTSTATUS dcerpc_samr_QueryDomainInfo2(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      struct policy_handle *_domain_handle /* [in] [ref] */,
 				      enum samr_DomainInfoClass _level /* [in]  */,
-				      union samr_DomainInfo **_info /* [out] [switch_is(level),ref] */,
+				      union samr_DomainInfo **_info /* [out] [ref,switch_is(level)] */,
 				      NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_QueryUserInfo2_r_send(TALLOC_CTX *mem_ctx,
@@ -1107,7 +1107,7 @@ struct tevent_req *dcerpc_samr_QueryDisplayInfo2_send(TALLOC_CTX *mem_ctx,
 						      uint32_t _buf_size /* [in]  */,
 						      uint32_t *_total_size /* [out] [ref] */,
 						      uint32_t *_returned_size /* [out] [ref] */,
-						      union samr_DispInfo *_info /* [out] [ref,switch_is(level)] */);
+						      union samr_DispInfo *_info /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_QueryDisplayInfo2_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    NTSTATUS *result);
@@ -1120,7 +1120,7 @@ NTSTATUS dcerpc_samr_QueryDisplayInfo2(struct dcerpc_binding_handle *h,
 				       uint32_t _buf_size /* [in]  */,
 				       uint32_t *_total_size /* [out] [ref] */,
 				       uint32_t *_returned_size /* [out] [ref] */,
-				       union samr_DispInfo *_info /* [out] [ref,switch_is(level)] */,
+				       union samr_DispInfo *_info /* [out] [switch_is(level),ref] */,
 				       NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_GetDisplayEnumerationIndex2_r_send(TALLOC_CTX *mem_ctx,
@@ -1193,7 +1193,7 @@ struct tevent_req *dcerpc_samr_QueryDisplayInfo3_send(TALLOC_CTX *mem_ctx,
 						      uint32_t _buf_size /* [in]  */,
 						      uint32_t *_total_size /* [out] [ref] */,
 						      uint32_t *_returned_size /* [out] [ref] */,
-						      union samr_DispInfo *_info /* [out] [ref,switch_is(level)] */);
+						      union samr_DispInfo *_info /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_QueryDisplayInfo3_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    NTSTATUS *result);
@@ -1206,7 +1206,7 @@ NTSTATUS dcerpc_samr_QueryDisplayInfo3(struct dcerpc_binding_handle *h,
 				       uint32_t _buf_size /* [in]  */,
 				       uint32_t *_total_size /* [out] [ref] */,
 				       uint32_t *_returned_size /* [out] [ref] */,
-				       union samr_DispInfo *_info /* [out] [ref,switch_is(level)] */,
+				       union samr_DispInfo *_info /* [out] [switch_is(level),ref] */,
 				       NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_AddMultipleMembersToAlias_r_send(TALLOC_CTX *mem_ctx,
@@ -1504,24 +1504,24 @@ NTSTATUS dcerpc_samr_Connect5_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem
 struct tevent_req *dcerpc_samr_Connect5_send(TALLOC_CTX *mem_ctx,
 					     struct tevent_context *ev,
 					     struct dcerpc_binding_handle *h,
-					     const char *_system_name /* [in] [unique,charset(UTF16)] */,
+					     const char *_system_name /* [in] [charset(UTF16),unique] */,
 					     uint32_t _access_mask /* [in]  */,
 					     uint32_t _level_in /* [in]  */,
-					     union samr_ConnectInfo *_info_in /* [in] [switch_is(level_in),ref] */,
+					     union samr_ConnectInfo *_info_in /* [in] [ref,switch_is(level_in)] */,
 					     uint32_t *_level_out /* [out] [ref] */,
-					     union samr_ConnectInfo *_info_out /* [out] [switch_is(*level_out),ref] */,
+					     union samr_ConnectInfo *_info_out /* [out] [ref,switch_is(*level_out)] */,
 					     struct policy_handle *_connect_handle /* [out] [ref] */);
 NTSTATUS dcerpc_samr_Connect5_recv(struct tevent_req *req,
 				   TALLOC_CTX *mem_ctx,
 				   NTSTATUS *result);
 NTSTATUS dcerpc_samr_Connect5(struct dcerpc_binding_handle *h,
 			      TALLOC_CTX *mem_ctx,
-			      const char *_system_name /* [in] [unique,charset(UTF16)] */,
+			      const char *_system_name /* [in] [charset(UTF16),unique] */,
 			      uint32_t _access_mask /* [in]  */,
 			      uint32_t _level_in /* [in]  */,
-			      union samr_ConnectInfo *_info_in /* [in] [switch_is(level_in),ref] */,
+			      union samr_ConnectInfo *_info_in /* [in] [ref,switch_is(level_in)] */,
 			      uint32_t *_level_out /* [out] [ref] */,
-			      union samr_ConnectInfo *_info_out /* [out] [switch_is(*level_out),ref] */,
+			      union samr_ConnectInfo *_info_out /* [out] [ref,switch_is(*level_out)] */,
 			      struct policy_handle *_connect_handle /* [out] [ref] */,
 			      NTSTATUS *result);
 
