@@ -14,7 +14,7 @@ NTSTATUS dcerpc_srvsvc_NetCharDevEnum_r(struct dcerpc_binding_handle *h, TALLOC_
 struct tevent_req *dcerpc_srvsvc_NetCharDevEnum_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
-						     const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						     const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						     struct srvsvc_NetCharDevInfoCtr *_info_ctr /* [in,out] [ref] */,
 						     uint32_t _max_buffer /* [in]  */,
 						     uint32_t *_totalentries /* [out] [ref] */,
@@ -24,7 +24,7 @@ NTSTATUS dcerpc_srvsvc_NetCharDevEnum_recv(struct tevent_req *req,
 					   WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetCharDevEnum(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
-				      const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				      struct srvsvc_NetCharDevInfoCtr *_info_ctr /* [in,out] [ref] */,
 				      uint32_t _max_buffer /* [in]  */,
 				      uint32_t *_totalentries /* [out] [ref] */,
@@ -87,7 +87,7 @@ struct tevent_req *dcerpc_srvsvc_NetCharDevQEnum_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
 						      const char *_server_unc /* [in] [charset(UTF16),unique] */,
-						      const char *_user /* [in] [unique,charset(UTF16)] */,
+						      const char *_user /* [in] [charset(UTF16),unique] */,
 						      struct srvsvc_NetCharDevQInfoCtr *_info_ctr /* [in,out] [ref] */,
 						      uint32_t _max_buffer /* [in]  */,
 						      uint32_t *_totalentries /* [out] [ref] */,
@@ -98,7 +98,7 @@ NTSTATUS dcerpc_srvsvc_NetCharDevQEnum_recv(struct tevent_req *req,
 NTSTATUS dcerpc_srvsvc_NetCharDevQEnum(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
 				       const char *_server_unc /* [in] [charset(UTF16),unique] */,
-				       const char *_user /* [in] [unique,charset(UTF16)] */,
+				       const char *_user /* [in] [charset(UTF16),unique] */,
 				       struct srvsvc_NetCharDevQInfoCtr *_info_ctr /* [in,out] [ref] */,
 				       uint32_t _max_buffer /* [in]  */,
 				       uint32_t *_totalentries /* [out] [ref] */,
@@ -186,7 +186,7 @@ NTSTATUS dcerpc_srvsvc_NetCharDevQPurgeSelf_r(struct dcerpc_binding_handle *h, T
 struct tevent_req *dcerpc_srvsvc_NetCharDevQPurgeSelf_send(TALLOC_CTX *mem_ctx,
 							   struct tevent_context *ev,
 							   struct dcerpc_binding_handle *h,
-							   const char *_server_unc /* [in] [charset(UTF16),unique] */,
+							   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 							   const char *_queue_name /* [in] [charset(UTF16)] */,
 							   const char *_computer_name /* [in] [charset(UTF16)] */);
 NTSTATUS dcerpc_srvsvc_NetCharDevQPurgeSelf_recv(struct tevent_req *req,
@@ -194,7 +194,7 @@ NTSTATUS dcerpc_srvsvc_NetCharDevQPurgeSelf_recv(struct tevent_req *req,
 						 WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetCharDevQPurgeSelf(struct dcerpc_binding_handle *h,
 					    TALLOC_CTX *mem_ctx,
-					    const char *_server_unc /* [in] [charset(UTF16),unique] */,
+					    const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 					    const char *_queue_name /* [in] [charset(UTF16)] */,
 					    const char *_computer_name /* [in] [charset(UTF16)] */,
 					    WERROR *result);
@@ -208,8 +208,8 @@ NTSTATUS dcerpc_srvsvc_NetConnEnum_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_srvsvc_NetConnEnum_send(TALLOC_CTX *mem_ctx,
 						  struct tevent_context *ev,
 						  struct dcerpc_binding_handle *h,
-						  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-						  const char *_path /* [in] [charset(UTF16),unique] */,
+						  const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						  const char *_path /* [in] [unique,charset(UTF16)] */,
 						  struct srvsvc_NetConnInfoCtr *_info_ctr /* [in,out] [ref] */,
 						  uint32_t _max_buffer /* [in]  */,
 						  uint32_t *_totalentries /* [out] [ref] */,
@@ -219,8 +219,8 @@ NTSTATUS dcerpc_srvsvc_NetConnEnum_recv(struct tevent_req *req,
 					WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetConnEnum(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
-				   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-				   const char *_path /* [in] [charset(UTF16),unique] */,
+				   const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				   const char *_path /* [in] [unique,charset(UTF16)] */,
 				   struct srvsvc_NetConnInfoCtr *_info_ctr /* [in,out] [ref] */,
 				   uint32_t _max_buffer /* [in]  */,
 				   uint32_t *_totalentries /* [out] [ref] */,
@@ -236,9 +236,9 @@ NTSTATUS dcerpc_srvsvc_NetFileEnum_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_srvsvc_NetFileEnum_send(TALLOC_CTX *mem_ctx,
 						  struct tevent_context *ev,
 						  struct dcerpc_binding_handle *h,
-						  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-						  const char *_path /* [in] [unique,charset(UTF16)] */,
-						  const char *_user /* [in] [charset(UTF16),unique] */,
+						  const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						  const char *_path /* [in] [charset(UTF16),unique] */,
+						  const char *_user /* [in] [unique,charset(UTF16)] */,
 						  struct srvsvc_NetFileInfoCtr *_info_ctr /* [in,out] [ref] */,
 						  uint32_t _max_buffer /* [in]  */,
 						  uint32_t *_totalentries /* [out] [ref] */,
@@ -248,9 +248,9 @@ NTSTATUS dcerpc_srvsvc_NetFileEnum_recv(struct tevent_req *req,
 					WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetFileEnum(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
-				   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-				   const char *_path /* [in] [unique,charset(UTF16)] */,
-				   const char *_user /* [in] [charset(UTF16),unique] */,
+				   const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				   const char *_path /* [in] [charset(UTF16),unique] */,
+				   const char *_user /* [in] [unique,charset(UTF16)] */,
 				   struct srvsvc_NetFileInfoCtr *_info_ctr /* [in,out] [ref] */,
 				   uint32_t _max_buffer /* [in]  */,
 				   uint32_t *_totalentries /* [out] [ref] */,
@@ -290,14 +290,14 @@ NTSTATUS dcerpc_srvsvc_NetFileClose_r(struct dcerpc_binding_handle *h, TALLOC_CT
 struct tevent_req *dcerpc_srvsvc_NetFileClose_send(TALLOC_CTX *mem_ctx,
 						   struct tevent_context *ev,
 						   struct dcerpc_binding_handle *h,
-						   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						   const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						   uint32_t _fid /* [in]  */);
 NTSTATUS dcerpc_srvsvc_NetFileClose_recv(struct tevent_req *req,
 					 TALLOC_CTX *mem_ctx,
 					 WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetFileClose(struct dcerpc_binding_handle *h,
 				    TALLOC_CTX *mem_ctx,
-				    const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+				    const char *_server_unc /* [in] [charset(UTF16),unique] */,
 				    uint32_t _fid /* [in]  */,
 				    WERROR *result);
 
@@ -310,8 +310,8 @@ NTSTATUS dcerpc_srvsvc_NetSessEnum_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_srvsvc_NetSessEnum_send(TALLOC_CTX *mem_ctx,
 						  struct tevent_context *ev,
 						  struct dcerpc_binding_handle *h,
-						  const char *_server_unc /* [in] [charset(UTF16),unique] */,
-						  const char *_client /* [in] [charset(UTF16),unique] */,
+						  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						  const char *_client /* [in] [unique,charset(UTF16)] */,
 						  const char *_user /* [in] [charset(UTF16),unique] */,
 						  struct srvsvc_NetSessInfoCtr *_info_ctr /* [in,out] [ref] */,
 						  uint32_t _max_buffer /* [in]  */,
@@ -322,8 +322,8 @@ NTSTATUS dcerpc_srvsvc_NetSessEnum_recv(struct tevent_req *req,
 					WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetSessEnum(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
-				   const char *_server_unc /* [in] [charset(UTF16),unique] */,
-				   const char *_client /* [in] [charset(UTF16),unique] */,
+				   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+				   const char *_client /* [in] [unique,charset(UTF16)] */,
 				   const char *_user /* [in] [charset(UTF16),unique] */,
 				   struct srvsvc_NetSessInfoCtr *_info_ctr /* [in,out] [ref] */,
 				   uint32_t _max_buffer /* [in]  */,
@@ -342,7 +342,7 @@ struct tevent_req *dcerpc_srvsvc_NetSessDel_send(TALLOC_CTX *mem_ctx,
 						 struct dcerpc_binding_handle *h,
 						 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						 const char *_client /* [in] [charset(UTF16),unique] */,
-						 const char *_user /* [in] [unique,charset(UTF16)] */);
+						 const char *_user /* [in] [charset(UTF16),unique] */);
 NTSTATUS dcerpc_srvsvc_NetSessDel_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
 				       WERROR *result);
@@ -350,7 +350,7 @@ NTSTATUS dcerpc_srvsvc_NetSessDel(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				  const char *_client /* [in] [charset(UTF16),unique] */,
-				  const char *_user /* [in] [unique,charset(UTF16)] */,
+				  const char *_user /* [in] [charset(UTF16),unique] */,
 				  WERROR *result);
 
 struct tevent_req *dcerpc_srvsvc_NetShareAdd_r_send(TALLOC_CTX *mem_ctx,
@@ -362,7 +362,7 @@ NTSTATUS dcerpc_srvsvc_NetShareAdd_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_srvsvc_NetShareAdd_send(TALLOC_CTX *mem_ctx,
 						  struct tevent_context *ev,
 						  struct dcerpc_binding_handle *h,
-						  const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						  uint32_t _level /* [in]  */,
 						  union srvsvc_NetShareInfo *_info /* [in] [switch_is(level),ref] */,
 						  uint32_t *_parm_error /* [in,out] [unique] */);
@@ -371,7 +371,7 @@ NTSTATUS dcerpc_srvsvc_NetShareAdd_recv(struct tevent_req *req,
 					WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetShareAdd(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
-				   const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				   uint32_t _level /* [in]  */,
 				   union srvsvc_NetShareInfo *_info /* [in] [switch_is(level),ref] */,
 				   uint32_t *_parm_error /* [in,out] [unique] */,
@@ -412,7 +412,7 @@ NTSTATUS dcerpc_srvsvc_NetShareGetInfo_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_srvsvc_NetShareGetInfo_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						      const char *_share_name /* [in] [charset(UTF16)] */,
 						      uint32_t _level /* [in]  */,
 						      union srvsvc_NetShareInfo *_info /* [out] [ref,switch_is(level)] */);
@@ -421,7 +421,7 @@ NTSTATUS dcerpc_srvsvc_NetShareGetInfo_recv(struct tevent_req *req,
 					    WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetShareGetInfo(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				       const char *_share_name /* [in] [charset(UTF16)] */,
 				       uint32_t _level /* [in]  */,
 				       union srvsvc_NetShareInfo *_info /* [out] [ref,switch_is(level)] */,
@@ -436,20 +436,20 @@ NTSTATUS dcerpc_srvsvc_NetShareSetInfo_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_srvsvc_NetShareSetInfo_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						      const char *_share_name /* [in] [charset(UTF16)] */,
 						      uint32_t _level /* [in]  */,
-						      union srvsvc_NetShareInfo *_info /* [in] [ref,switch_is(level)] */,
+						      union srvsvc_NetShareInfo *_info /* [in] [switch_is(level),ref] */,
 						      uint32_t *_parm_error /* [in,out] [unique] */);
 NTSTATUS dcerpc_srvsvc_NetShareSetInfo_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetShareSetInfo(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				       const char *_share_name /* [in] [charset(UTF16)] */,
 				       uint32_t _level /* [in]  */,
-				       union srvsvc_NetShareInfo *_info /* [in] [ref,switch_is(level)] */,
+				       union srvsvc_NetShareInfo *_info /* [in] [switch_is(level),ref] */,
 				       uint32_t *_parm_error /* [in,out] [unique] */,
 				       WERROR *result);
 
@@ -484,7 +484,7 @@ NTSTATUS dcerpc_srvsvc_NetShareDelSticky_r(struct dcerpc_binding_handle *h, TALL
 struct tevent_req *dcerpc_srvsvc_NetShareDelSticky_send(TALLOC_CTX *mem_ctx,
 							struct tevent_context *ev,
 							struct dcerpc_binding_handle *h,
-							const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+							const char *_server_unc /* [in] [charset(UTF16),unique] */,
 							const char *_share_name /* [in] [charset(UTF16)] */,
 							uint32_t _reserved /* [in]  */);
 NTSTATUS dcerpc_srvsvc_NetShareDelSticky_recv(struct tevent_req *req,
@@ -492,7 +492,7 @@ NTSTATUS dcerpc_srvsvc_NetShareDelSticky_recv(struct tevent_req *req,
 					      WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetShareDelSticky(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
-					 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					 const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					 const char *_share_name /* [in] [charset(UTF16)] */,
 					 uint32_t _reserved /* [in]  */,
 					 WERROR *result);
@@ -528,7 +528,7 @@ NTSTATUS dcerpc_srvsvc_NetSrvGetInfo_r(struct dcerpc_binding_handle *h, TALLOC_C
 struct tevent_req *dcerpc_srvsvc_NetSrvGetInfo_send(TALLOC_CTX *mem_ctx,
 						    struct tevent_context *ev,
 						    struct dcerpc_binding_handle *h,
-						    const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						    const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						    uint32_t _level /* [in]  */,
 						    union srvsvc_NetSrvInfo *_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_srvsvc_NetSrvGetInfo_recv(struct tevent_req *req,
@@ -536,7 +536,7 @@ NTSTATUS dcerpc_srvsvc_NetSrvGetInfo_recv(struct tevent_req *req,
 					  WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetSrvGetInfo(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
-				     const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				     const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				     uint32_t _level /* [in]  */,
 				     union srvsvc_NetSrvInfo *_info /* [out] [ref,switch_is(level)] */,
 				     WERROR *result);
@@ -552,7 +552,7 @@ struct tevent_req *dcerpc_srvsvc_NetSrvSetInfo_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						    uint32_t _level /* [in]  */,
-						    union srvsvc_NetSrvInfo *_info /* [in] [ref,switch_is(level)] */,
+						    union srvsvc_NetSrvInfo *_info /* [in] [switch_is(level),ref] */,
 						    uint32_t *_parm_error /* [in,out] [unique] */);
 NTSTATUS dcerpc_srvsvc_NetSrvSetInfo_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
@@ -561,7 +561,7 @@ NTSTATUS dcerpc_srvsvc_NetSrvSetInfo(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     const char *_server_unc /* [in] [charset(UTF16),unique] */,
 				     uint32_t _level /* [in]  */,
-				     union srvsvc_NetSrvInfo *_info /* [in] [ref,switch_is(level)] */,
+				     union srvsvc_NetSrvInfo *_info /* [in] [switch_is(level),ref] */,
 				     uint32_t *_parm_error /* [in,out] [unique] */,
 				     WERROR *result);
 
@@ -676,7 +676,7 @@ NTSTATUS dcerpc_srvsvc_NetTransportDel_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_srvsvc_NetTransportDel_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						      const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						      uint32_t _level /* [in]  */,
 						      struct srvsvc_NetTransportInfo0 *_info0 /* [in] [ref] */);
 NTSTATUS dcerpc_srvsvc_NetTransportDel_recv(struct tevent_req *req,
@@ -684,7 +684,7 @@ NTSTATUS dcerpc_srvsvc_NetTransportDel_recv(struct tevent_req *req,
 					    WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetTransportDel(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+				       const char *_server_unc /* [in] [charset(UTF16),unique] */,
 				       uint32_t _level /* [in]  */,
 				       struct srvsvc_NetTransportInfo0 *_info0 /* [in] [ref] */,
 				       WERROR *result);
@@ -698,14 +698,14 @@ NTSTATUS dcerpc_srvsvc_NetRemoteTOD_r(struct dcerpc_binding_handle *h, TALLOC_CT
 struct tevent_req *dcerpc_srvsvc_NetRemoteTOD_send(TALLOC_CTX *mem_ctx,
 						   struct tevent_context *ev,
 						   struct dcerpc_binding_handle *h,
-						   const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						   struct srvsvc_NetRemoteTODInfo **_info /* [out] [ref] */);
 NTSTATUS dcerpc_srvsvc_NetRemoteTOD_recv(struct tevent_req *req,
 					 TALLOC_CTX *mem_ctx,
 					 WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetRemoteTOD(struct dcerpc_binding_handle *h,
 				    TALLOC_CTX *mem_ctx,
-				    const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				    const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				    struct srvsvc_NetRemoteTODInfo **_info /* [out] [ref] */,
 				    WERROR *result);
 
@@ -718,7 +718,7 @@ NTSTATUS dcerpc_srvsvc_NetSetServiceBits_r(struct dcerpc_binding_handle *h, TALL
 struct tevent_req *dcerpc_srvsvc_NetSetServiceBits_send(TALLOC_CTX *mem_ctx,
 							struct tevent_context *ev,
 							struct dcerpc_binding_handle *h,
-							const char *_server_unc /* [in] [charset(UTF16),unique] */,
+							const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 							const char *_transport /* [in] [charset(UTF16),unique] */,
 							uint32_t _servicebits /* [in]  */,
 							uint32_t _updateimmediately /* [in]  */);
@@ -727,7 +727,7 @@ NTSTATUS dcerpc_srvsvc_NetSetServiceBits_recv(struct tevent_req *req,
 					      WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetSetServiceBits(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
-					 const char *_server_unc /* [in] [charset(UTF16),unique] */,
+					 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 					 const char *_transport /* [in] [charset(UTF16),unique] */,
 					 uint32_t _servicebits /* [in]  */,
 					 uint32_t _updateimmediately /* [in]  */,
@@ -766,7 +766,7 @@ NTSTATUS dcerpc_srvsvc_NetPathCanonicalize_r(struct dcerpc_binding_handle *h, TA
 struct tevent_req *dcerpc_srvsvc_NetPathCanonicalize_send(TALLOC_CTX *mem_ctx,
 							  struct tevent_context *ev,
 							  struct dcerpc_binding_handle *h,
-							  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+							  const char *_server_unc /* [in] [charset(UTF16),unique] */,
 							  const char *_path /* [in] [charset(UTF16)] */,
 							  uint8_t *_can_path /* [out] [size_is(maxbuf)] */,
 							  uint32_t _maxbuf /* [in]  */,
@@ -778,7 +778,7 @@ NTSTATUS dcerpc_srvsvc_NetPathCanonicalize_recv(struct tevent_req *req,
 						WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetPathCanonicalize(struct dcerpc_binding_handle *h,
 					   TALLOC_CTX *mem_ctx,
-					   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					   const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					   const char *_path /* [in] [charset(UTF16)] */,
 					   uint8_t *_can_path /* [out] [size_is(maxbuf)] */,
 					   uint32_t _maxbuf /* [in]  */,
@@ -872,7 +872,7 @@ NTSTATUS dcerpc_srvsvc_NetShareEnum_r(struct dcerpc_binding_handle *h, TALLOC_CT
 struct tevent_req *dcerpc_srvsvc_NetShareEnum_send(TALLOC_CTX *mem_ctx,
 						   struct tevent_context *ev,
 						   struct dcerpc_binding_handle *h,
-						   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						   const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						   struct srvsvc_NetShareInfoCtr *_info_ctr /* [in,out] [ref] */,
 						   uint32_t _max_buffer /* [in]  */,
 						   uint32_t *_totalentries /* [out] [ref] */,
@@ -882,7 +882,7 @@ NTSTATUS dcerpc_srvsvc_NetShareEnum_recv(struct tevent_req *req,
 					 WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetShareEnum(struct dcerpc_binding_handle *h,
 				    TALLOC_CTX *mem_ctx,
-				    const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+				    const char *_server_unc /* [in] [charset(UTF16),unique] */,
 				    struct srvsvc_NetShareInfoCtr *_info_ctr /* [in,out] [ref] */,
 				    uint32_t _max_buffer /* [in]  */,
 				    uint32_t *_totalentries /* [out] [ref] */,
@@ -940,7 +940,7 @@ NTSTATUS dcerpc_srvsvc_NetGetFileSecurity_r(struct dcerpc_binding_handle *h, TAL
 struct tevent_req *dcerpc_srvsvc_NetGetFileSecurity_send(TALLOC_CTX *mem_ctx,
 							 struct tevent_context *ev,
 							 struct dcerpc_binding_handle *h,
-							 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+							 const char *_server_unc /* [in] [charset(UTF16),unique] */,
 							 const char *_share /* [in] [charset(UTF16),unique] */,
 							 const char *_file /* [in] [charset(UTF16)] */,
 							 uint32_t _securityinformation /* [in]  */,
@@ -950,7 +950,7 @@ NTSTATUS dcerpc_srvsvc_NetGetFileSecurity_recv(struct tevent_req *req,
 					       WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetGetFileSecurity(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
-					  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					  const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					  const char *_share /* [in] [charset(UTF16),unique] */,
 					  const char *_file /* [in] [charset(UTF16)] */,
 					  uint32_t _securityinformation /* [in]  */,
@@ -967,7 +967,7 @@ struct tevent_req *dcerpc_srvsvc_NetSetFileSecurity_send(TALLOC_CTX *mem_ctx,
 							 struct tevent_context *ev,
 							 struct dcerpc_binding_handle *h,
 							 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-							 const char *_share /* [in] [unique,charset(UTF16)] */,
+							 const char *_share /* [in] [charset(UTF16),unique] */,
 							 const char *_file /* [in] [charset(UTF16)] */,
 							 uint32_t _securityinformation /* [in]  */,
 							 struct sec_desc_buf *_sd_buf /* [in] [ref] */);
@@ -977,7 +977,7 @@ NTSTATUS dcerpc_srvsvc_NetSetFileSecurity_recv(struct tevent_req *req,
 NTSTATUS dcerpc_srvsvc_NetSetFileSecurity(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
 					  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-					  const char *_share /* [in] [unique,charset(UTF16)] */,
+					  const char *_share /* [in] [charset(UTF16),unique] */,
 					  const char *_file /* [in] [charset(UTF16)] */,
 					  uint32_t _securityinformation /* [in]  */,
 					  struct sec_desc_buf *_sd_buf /* [in] [ref] */,
@@ -1014,9 +1014,9 @@ NTSTATUS dcerpc_srvsvc_NetServerSetServiceBitsEx_r(struct dcerpc_binding_handle
 struct tevent_req *dcerpc_srvsvc_NetServerSetServiceBitsEx_send(TALLOC_CTX *mem_ctx,
 								struct tevent_context *ev,
 								struct dcerpc_binding_handle *h,
-								const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-								const char *_emulated_server_unc /* [in] [unique,charset(UTF16)] */,
-								const char *_transport /* [in] [unique,charset(UTF16)] */,
+								const char *_server_unc /* [in] [charset(UTF16),unique] */,
+								const char *_emulated_server_unc /* [in] [charset(UTF16),unique] */,
+								const char *_transport /* [in] [charset(UTF16),unique] */,
 								uint32_t _servicebitsofinterest /* [in]  */,
 								uint32_t _servicebits /* [in]  */,
 								uint32_t _updateimmediately /* [in]  */);
@@ -1025,9 +1025,9 @@ NTSTATUS dcerpc_srvsvc_NetServerSetServiceBitsEx_recv(struct tevent_req *req,
 						      WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetServerSetServiceBitsEx(struct dcerpc_binding_handle *h,
 						 TALLOC_CTX *mem_ctx,
-						 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-						 const char *_emulated_server_unc /* [in] [unique,charset(UTF16)] */,
-						 const char *_transport /* [in] [unique,charset(UTF16)] */,
+						 const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						 const char *_emulated_server_unc /* [in] [charset(UTF16),unique] */,
+						 const char *_transport /* [in] [charset(UTF16),unique] */,
 						 uint32_t _servicebitsofinterest /* [in]  */,
 						 uint32_t _servicebits /* [in]  */,
 						 uint32_t _updateimmediately /* [in]  */,
