@@ -96,7 +96,7 @@ struct tevent_req *dcerpc_svcctl_QueryServiceObjectSecurity_send(TALLOC_CTX *mem
 								 uint32_t _security_flags /* [in]  */,
 								 uint8_t *_buffer /* [out] [ref,size_is(offered)] */,
 								 uint32_t _offered /* [in] [range(0,0x40000)] */,
-								 uint32_t *_needed /* [out] [range(0,0x40000),ref] */);
+								 uint32_t *_needed /* [out] [ref,range(0,0x40000)] */);
 NTSTATUS dcerpc_svcctl_QueryServiceObjectSecurity_recv(struct tevent_req *req,
 						       TALLOC_CTX *mem_ctx,
 						       WERROR *result);
@@ -106,7 +106,7 @@ NTSTATUS dcerpc_svcctl_QueryServiceObjectSecurity(struct dcerpc_binding_handle *
 						  uint32_t _security_flags /* [in]  */,
 						  uint8_t *_buffer /* [out] [ref,size_is(offered)] */,
 						  uint32_t _offered /* [in] [range(0,0x40000)] */,
-						  uint32_t *_needed /* [out] [range(0,0x40000),ref] */,
+						  uint32_t *_needed /* [out] [ref,range(0,0x40000)] */,
 						  WERROR *result);
 
 struct tevent_req *dcerpc_svcctl_SetServiceObjectSecurity_r_send(TALLOC_CTX *mem_ctx,
@@ -208,13 +208,13 @@ struct tevent_req *dcerpc_svcctl_ChangeServiceConfigW_send(TALLOC_CTX *mem_ctx,
 							   uint32_t _type /* [in]  */,
 							   enum svcctl_StartType _start_type /* [in]  */,
 							   enum svcctl_ErrorControl _error_control /* [in]  */,
-							   const char *_binary_path /* [in] [charset(UTF16),unique] */,
-							   const char *_load_order_group /* [in] [charset(UTF16),unique] */,
+							   const char *_binary_path /* [in] [unique,charset(UTF16)] */,
+							   const char *_load_order_group /* [in] [unique,charset(UTF16)] */,
 							   uint32_t *_tag_id /* [out] [ref] */,
 							   const char *_dependencies /* [in] [charset(UTF16),unique] */,
 							   const char *_service_start_name /* [in] [unique,charset(UTF16)] */,
-							   const char *_password /* [in] [charset(UTF16),unique] */,
-							   const char *_display_name /* [in] [unique,charset(UTF16)] */);
+							   const char *_password /* [in] [unique,charset(UTF16)] */,
+							   const char *_display_name /* [in] [charset(UTF16),unique] */);
 NTSTATUS dcerpc_svcctl_ChangeServiceConfigW_recv(struct tevent_req *req,
 						 TALLOC_CTX *mem_ctx,
 						 WERROR *result);
@@ -224,13 +224,13 @@ NTSTATUS dcerpc_svcctl_ChangeServiceConfigW(struct dcerpc_binding_handle *h,
 					    uint32_t _type /* [in]  */,
 					    enum svcctl_StartType _start_type /* [in]  */,
 					    enum svcctl_ErrorControl _error_control /* [in]  */,
-					    const char *_binary_path /* [in] [charset(UTF16),unique] */,
-					    const char *_load_order_group /* [in] [charset(UTF16),unique] */,
+					    const char *_binary_path /* [in] [unique,charset(UTF16)] */,
+					    const char *_load_order_group /* [in] [unique,charset(UTF16)] */,
 					    uint32_t *_tag_id /* [out] [ref] */,
 					    const char *_dependencies /* [in] [charset(UTF16),unique] */,
 					    const char *_service_start_name /* [in] [unique,charset(UTF16)] */,
-					    const char *_password /* [in] [charset(UTF16),unique] */,
-					    const char *_display_name /* [in] [unique,charset(UTF16)] */,
+					    const char *_password /* [in] [unique,charset(UTF16)] */,
+					    const char *_display_name /* [in] [charset(UTF16),unique] */,
 					    WERROR *result);
 
 struct tevent_req *dcerpc_svcctl_CreateServiceW_r_send(TALLOC_CTX *mem_ctx,
@@ -244,7 +244,7 @@ struct tevent_req *dcerpc_svcctl_CreateServiceW_send(TALLOC_CTX *mem_ctx,
 						     struct dcerpc_binding_handle *h,
 						     struct policy_handle *_scmanager_handle /* [in] [ref] */,
 						     const char *_ServiceName /* [in] [charset(UTF16)] */,
-						     const char *_DisplayName /* [in] [unique,charset(UTF16)] */,
+						     const char *_DisplayName /* [in] [charset(UTF16),unique] */,
 						     uint32_t _desired_access /* [in]  */,
 						     uint32_t _type /* [in]  */,
 						     enum svcctl_StartType _start_type /* [in]  */,
@@ -252,7 +252,7 @@ struct tevent_req *dcerpc_svcctl_CreateServiceW_send(TALLOC_CTX *mem_ctx,
 						     const char *_binary_path /* [in] [charset(UTF16)] */,
 						     const char *_LoadOrderGroupKey /* [in] [charset(UTF16),unique] */,
 						     uint32_t *_TagId /* [in,out] [unique] */,
-						     uint8_t *_dependencies /* [in] [size_is(dependencies_size),unique] */,
+						     uint8_t *_dependencies /* [in] [unique,size_is(dependencies_size)] */,
 						     uint32_t _dependencies_size /* [in]  */,
 						     const char *_service_start_name /* [in] [charset(UTF16),unique] */,
 						     uint8_t *_password /* [in] [unique,size_is(password_size)] */,
@@ -265,7 +265,7 @@ NTSTATUS dcerpc_svcctl_CreateServiceW(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      struct policy_handle *_scmanager_handle /* [in] [ref] */,
 				      const char *_ServiceName /* [in] [charset(UTF16)] */,
-				      const char *_DisplayName /* [in] [unique,charset(UTF16)] */,
+				      const char *_DisplayName /* [in] [charset(UTF16),unique] */,
 				      uint32_t _desired_access /* [in]  */,
 				      uint32_t _type /* [in]  */,
 				      enum svcctl_StartType _start_type /* [in]  */,
@@ -273,7 +273,7 @@ NTSTATUS dcerpc_svcctl_CreateServiceW(struct dcerpc_binding_handle *h,
 				      const char *_binary_path /* [in] [charset(UTF16)] */,
 				      const char *_LoadOrderGroupKey /* [in] [charset(UTF16),unique] */,
 				      uint32_t *_TagId /* [in,out] [unique] */,
-				      uint8_t *_dependencies /* [in] [size_is(dependencies_size),unique] */,
+				      uint8_t *_dependencies /* [in] [unique,size_is(dependencies_size)] */,
 				      uint32_t _dependencies_size /* [in]  */,
 				      const char *_service_start_name /* [in] [charset(UTF16),unique] */,
 				      uint8_t *_password /* [in] [unique,size_is(password_size)] */,
@@ -294,8 +294,8 @@ struct tevent_req *dcerpc_svcctl_EnumDependentServicesW_send(TALLOC_CTX *mem_ctx
 							     enum svcctl_ServiceState _state /* [in]  */,
 							     uint8_t *_service_status /* [out] [size_is(offered),ref] */,
 							     uint32_t _offered /* [in] [range(0,0x40000)] */,
-							     uint32_t *_needed /* [out] [ref,range(0,0x40000)] */,
-							     uint32_t *_services_returned /* [out] [range(0,0x40000),ref] */);
+							     uint32_t *_needed /* [out] [range(0,0x40000),ref] */,
+							     uint32_t *_services_returned /* [out] [ref,range(0,0x40000)] */);
 NTSTATUS dcerpc_svcctl_EnumDependentServicesW_recv(struct tevent_req *req,
 						   TALLOC_CTX *mem_ctx,
 						   WERROR *result);
@@ -305,8 +305,8 @@ NTSTATUS dcerpc_svcctl_EnumDependentServicesW(struct dcerpc_binding_handle *h,
 					      enum svcctl_ServiceState _state /* [in]  */,
 					      uint8_t *_service_status /* [out] [size_is(offered),ref] */,
 					      uint32_t _offered /* [in] [range(0,0x40000)] */,
-					      uint32_t *_needed /* [out] [ref,range(0,0x40000)] */,
-					      uint32_t *_services_returned /* [out] [range(0,0x40000),ref] */,
+					      uint32_t *_needed /* [out] [range(0,0x40000),ref] */,
+					      uint32_t *_services_returned /* [out] [ref,range(0,0x40000)] */,
 					      WERROR *result);
 
 struct tevent_req *dcerpc_svcctl_EnumServicesStatusW_r_send(TALLOC_CTX *mem_ctx,
@@ -350,8 +350,8 @@ NTSTATUS dcerpc_svcctl_OpenSCManagerW_r(struct dcerpc_binding_handle *h, TALLOC_
 struct tevent_req *dcerpc_svcctl_OpenSCManagerW_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
-						     const char *_MachineName /* [in] [unique,charset(UTF16)] */,
-						     const char *_DatabaseName /* [in] [charset(UTF16),unique] */,
+						     const char *_MachineName /* [in] [charset(UTF16),unique] */,
+						     const char *_DatabaseName /* [in] [unique,charset(UTF16)] */,
 						     uint32_t _access_mask /* [in]  */,
 						     struct policy_handle *_handle /* [out] [ref] */);
 NTSTATUS dcerpc_svcctl_OpenSCManagerW_recv(struct tevent_req *req,
@@ -359,8 +359,8 @@ NTSTATUS dcerpc_svcctl_OpenSCManagerW_recv(struct tevent_req *req,
 					   WERROR *result);
 NTSTATUS dcerpc_svcctl_OpenSCManagerW(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
-				      const char *_MachineName /* [in] [unique,charset(UTF16)] */,
-				      const char *_DatabaseName /* [in] [charset(UTF16),unique] */,
+				      const char *_MachineName /* [in] [charset(UTF16),unique] */,
+				      const char *_DatabaseName /* [in] [unique,charset(UTF16)] */,
 				      uint32_t _access_mask /* [in]  */,
 				      struct policy_handle *_handle /* [out] [ref] */,
 				      WERROR *result);
@@ -401,7 +401,7 @@ struct tevent_req *dcerpc_svcctl_QueryServiceConfigW_send(TALLOC_CTX *mem_ctx,
 							  struct policy_handle *_handle /* [in] [ref] */,
 							  struct QUERY_SERVICE_CONFIG *_query /* [out] [ref] */,
 							  uint32_t _offered /* [in] [range(0,8192)] */,
-							  uint32_t *_needed /* [out] [ref,range(0,8192)] */);
+							  uint32_t *_needed /* [out] [range(0,8192),ref] */);
 NTSTATUS dcerpc_svcctl_QueryServiceConfigW_recv(struct tevent_req *req,
 						TALLOC_CTX *mem_ctx,
 						WERROR *result);
@@ -410,7 +410,7 @@ NTSTATUS dcerpc_svcctl_QueryServiceConfigW(struct dcerpc_binding_handle *h,
 					   struct policy_handle *_handle /* [in] [ref] */,
 					   struct QUERY_SERVICE_CONFIG *_query /* [out] [ref] */,
 					   uint32_t _offered /* [in] [range(0,8192)] */,
-					   uint32_t *_needed /* [out] [ref,range(0,8192)] */,
+					   uint32_t *_needed /* [out] [range(0,8192),ref] */,
 					   WERROR *result);
 
 struct tevent_req *dcerpc_svcctl_QueryServiceLockStatusW_r_send(TALLOC_CTX *mem_ctx,
@@ -448,7 +448,7 @@ struct tevent_req *dcerpc_svcctl_StartServiceW_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    struct policy_handle *_handle /* [in] [ref] */,
 						    uint32_t _NumArgs /* [in] [range(0,SC_MAX_ARGUMENTS)] */,
-						    struct svcctl_ArgumentString *_Arguments /* [in] [size_is(NumArgs),unique] */);
+						    struct svcctl_ArgumentString *_Arguments /* [in] [unique,size_is(NumArgs)] */);
 NTSTATUS dcerpc_svcctl_StartServiceW_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
 					  WERROR *result);
@@ -456,7 +456,7 @@ NTSTATUS dcerpc_svcctl_StartServiceW(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     struct policy_handle *_handle /* [in] [ref] */,
 				     uint32_t _NumArgs /* [in] [range(0,SC_MAX_ARGUMENTS)] */,
-				     struct svcctl_ArgumentString *_Arguments /* [in] [size_is(NumArgs),unique] */,
+				     struct svcctl_ArgumentString *_Arguments /* [in] [unique,size_is(NumArgs)] */,
 				     WERROR *result);
 
 struct tevent_req *dcerpc_svcctl_GetServiceDisplayNameW_r_send(TALLOC_CTX *mem_ctx,
@@ -470,7 +470,7 @@ struct tevent_req *dcerpc_svcctl_GetServiceDisplayNameW_send(TALLOC_CTX *mem_ctx
 							     struct dcerpc_binding_handle *h,
 							     struct policy_handle *_handle /* [in] [ref] */,
 							     const char *_service_name /* [in] [charset(UTF16),unique] */,
-							     const char **_display_name /* [out] [ref,charset(UTF16)] */,
+							     const char **_display_name /* [out] [charset(UTF16),ref] */,
 							     uint32_t *_display_name_length /* [in,out] [unique] */);
 NTSTATUS dcerpc_svcctl_GetServiceDisplayNameW_recv(struct tevent_req *req,
 						   TALLOC_CTX *mem_ctx,
@@ -479,7 +479,7 @@ NTSTATUS dcerpc_svcctl_GetServiceDisplayNameW(struct dcerpc_binding_handle *h,
 					      TALLOC_CTX *mem_ctx,
 					      struct policy_handle *_handle /* [in] [ref] */,
 					      const char *_service_name /* [in] [charset(UTF16),unique] */,
-					      const char **_display_name /* [out] [ref,charset(UTF16)] */,
+					      const char **_display_name /* [out] [charset(UTF16),ref] */,
 					      uint32_t *_display_name_length /* [in,out] [unique] */,
 					      WERROR *result);
 
@@ -493,8 +493,8 @@ struct tevent_req *dcerpc_svcctl_GetServiceKeyNameW_send(TALLOC_CTX *mem_ctx,
 							 struct tevent_context *ev,
 							 struct dcerpc_binding_handle *h,
 							 struct policy_handle *_handle /* [in] [ref] */,
-							 const char *_service_name /* [in] [unique,charset(UTF16)] */,
-							 const char **_key_name /* [out] [ref,charset(UTF16)] */,
+							 const char *_service_name /* [in] [charset(UTF16),unique] */,
+							 const char **_key_name /* [out] [charset(UTF16),ref] */,
 							 uint32_t *_display_name_length /* [in,out] [unique] */);
 NTSTATUS dcerpc_svcctl_GetServiceKeyNameW_recv(struct tevent_req *req,
 					       TALLOC_CTX *mem_ctx,
@@ -502,8 +502,8 @@ NTSTATUS dcerpc_svcctl_GetServiceKeyNameW_recv(struct tevent_req *req,
 NTSTATUS dcerpc_svcctl_GetServiceKeyNameW(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
 					  struct policy_handle *_handle /* [in] [ref] */,
-					  const char *_service_name /* [in] [unique,charset(UTF16)] */,
-					  const char **_key_name /* [out] [ref,charset(UTF16)] */,
+					  const char *_service_name /* [in] [charset(UTF16),unique] */,
+					  const char **_key_name /* [out] [charset(UTF16),ref] */,
 					  uint32_t *_display_name_length /* [in,out] [unique] */,
 					  WERROR *result);
 
@@ -544,13 +544,13 @@ struct tevent_req *dcerpc_svcctl_ChangeServiceConfigA_send(TALLOC_CTX *mem_ctx,
 							   uint32_t _type /* [in]  */,
 							   enum svcctl_StartType _start_type /* [in]  */,
 							   enum svcctl_ErrorControl _error_control /* [in]  */,
-							   const char *_binary_path /* [in] [charset(UTF16),unique] */,
-							   const char *_load_order_group /* [in] [unique,charset(UTF16)] */,
+							   const char *_binary_path /* [in] [unique,charset(UTF16)] */,
+							   const char *_load_order_group /* [in] [charset(UTF16),unique] */,
 							   uint32_t *_tag_id /* [out] [ref] */,
-							   const char *_dependencies /* [in] [charset(UTF16),unique] */,
+							   const char *_dependencies /* [in] [unique,charset(UTF16)] */,
 							   const char *_service_start_name /* [in] [unique,charset(UTF16)] */,
-							   const char *_password /* [in] [unique,charset(UTF16)] */,
-							   const char *_display_name /* [in] [charset(UTF16),unique] */);
+							   const char *_password /* [in] [charset(UTF16),unique] */,
+							   const char *_display_name /* [in] [unique,charset(UTF16)] */);
 NTSTATUS dcerpc_svcctl_ChangeServiceConfigA_recv(struct tevent_req *req,
 						 TALLOC_CTX *mem_ctx,
 						 WERROR *result);
@@ -560,13 +560,13 @@ NTSTATUS dcerpc_svcctl_ChangeServiceConfigA(struct dcerpc_binding_handle *h,
 					    uint32_t _type /* [in]  */,
 					    enum svcctl_StartType _start_type /* [in]  */,
 					    enum svcctl_ErrorControl _error_control /* [in]  */,
-					    const char *_binary_path /* [in] [charset(UTF16),unique] */,
-					    const char *_load_order_group /* [in] [unique,charset(UTF16)] */,
+					    const char *_binary_path /* [in] [unique,charset(UTF16)] */,
+					    const char *_load_order_group /* [in] [charset(UTF16),unique] */,
 					    uint32_t *_tag_id /* [out] [ref] */,
-					    const char *_dependencies /* [in] [charset(UTF16),unique] */,
+					    const char *_dependencies /* [in] [unique,charset(UTF16)] */,
 					    const char *_service_start_name /* [in] [unique,charset(UTF16)] */,
-					    const char *_password /* [in] [unique,charset(UTF16)] */,
-					    const char *_display_name /* [in] [charset(UTF16),unique] */,
+					    const char *_password /* [in] [charset(UTF16),unique] */,
+					    const char *_display_name /* [in] [unique,charset(UTF16)] */,
 					    WERROR *result);
 
 struct tevent_req *dcerpc_svcctl_CreateServiceA_r_send(TALLOC_CTX *mem_ctx,
@@ -579,17 +579,17 @@ struct tevent_req *dcerpc_svcctl_CreateServiceA_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
 						     struct policy_handle *_handle /* [in] [ref] */,
-						     const char *_ServiceName /* [in] [unique,charset(UTF16)] */,
+						     const char *_ServiceName /* [in] [charset(UTF16),unique] */,
 						     const char *_DisplayName /* [in] [charset(UTF16),unique] */,
 						     uint32_t _desired_access /* [in]  */,
 						     uint32_t _type /* [in]  */,
 						     enum svcctl_StartType _start_type /* [in]  */,
 						     enum svcctl_ErrorControl _error_control /* [in]  */,
-						     const char *_binary_path /* [in] [charset(UTF16),unique] */,
+						     const char *_binary_path /* [in] [unique,charset(UTF16)] */,
 						     const char *_LoadOrderGroupKey /* [in] [charset(UTF16),unique] */,
 						     uint32_t *_TagId /* [out] [unique] */,
-						     const char *_dependencies /* [in] [unique,charset(UTF16)] */,
-						     const char *_service_start_name /* [in] [unique,charset(UTF16)] */,
+						     const char *_dependencies /* [in] [charset(UTF16),unique] */,
+						     const char *_service_start_name /* [in] [charset(UTF16),unique] */,
 						     const char *_password /* [in] [unique,charset(UTF16)] */);
 NTSTATUS dcerpc_svcctl_CreateServiceA_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
@@ -597,17 +597,17 @@ NTSTATUS dcerpc_svcctl_CreateServiceA_recv(struct tevent_req *req,
 NTSTATUS dcerpc_svcctl_CreateServiceA(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      struct policy_handle *_handle /* [in] [ref] */,
-				      const char *_ServiceName /* [in] [unique,charset(UTF16)] */,
+				      const char *_ServiceName /* [in] [charset(UTF16),unique] */,
 				      const char *_DisplayName /* [in] [charset(UTF16),unique] */,
 				      uint32_t _desired_access /* [in]  */,
 				      uint32_t _type /* [in]  */,
 				      enum svcctl_StartType _start_type /* [in]  */,
 				      enum svcctl_ErrorControl _error_control /* [in]  */,
-				      const char *_binary_path /* [in] [charset(UTF16),unique] */,
+				      const char *_binary_path /* [in] [unique,charset(UTF16)] */,
 				      const char *_LoadOrderGroupKey /* [in] [charset(UTF16),unique] */,
 				      uint32_t *_TagId /* [out] [unique] */,
-				      const char *_dependencies /* [in] [unique,charset(UTF16)] */,
-				      const char *_service_start_name /* [in] [unique,charset(UTF16)] */,
+				      const char *_dependencies /* [in] [charset(UTF16),unique] */,
+				      const char *_service_start_name /* [in] [charset(UTF16),unique] */,
 				      const char *_password /* [in] [unique,charset(UTF16)] */,
 				      WERROR *result);
 
@@ -680,8 +680,8 @@ NTSTATUS dcerpc_svcctl_OpenSCManagerA_r(struct dcerpc_binding_handle *h, TALLOC_
 struct tevent_req *dcerpc_svcctl_OpenSCManagerA_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
-						     const char *_MachineName /* [in] [charset(UTF16),unique] */,
-						     const char *_DatabaseName /* [in] [unique,charset(UTF16)] */,
+						     const char *_MachineName /* [in] [unique,charset(UTF16)] */,
+						     const char *_DatabaseName /* [in] [charset(UTF16),unique] */,
 						     uint32_t _access_mask /* [in]  */,
 						     struct policy_handle *_handle /* [out] [ref] */);
 NTSTATUS dcerpc_svcctl_OpenSCManagerA_recv(struct tevent_req *req,
@@ -689,8 +689,8 @@ NTSTATUS dcerpc_svcctl_OpenSCManagerA_recv(struct tevent_req *req,
 					   WERROR *result);
 NTSTATUS dcerpc_svcctl_OpenSCManagerA(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
-				      const char *_MachineName /* [in] [charset(UTF16),unique] */,
-				      const char *_DatabaseName /* [in] [unique,charset(UTF16)] */,
+				      const char *_MachineName /* [in] [unique,charset(UTF16)] */,
+				      const char *_DatabaseName /* [in] [charset(UTF16),unique] */,
 				      uint32_t _access_mask /* [in]  */,
 				      struct policy_handle *_handle /* [out] [ref] */,
 				      WERROR *result);
@@ -776,7 +776,7 @@ struct tevent_req *dcerpc_svcctl_StartServiceA_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    struct policy_handle *_handle /* [in] [ref] */,
 						    uint32_t _NumArgs /* [in]  */,
-						    const char *_Arguments /* [in] [unique,charset(UTF16)] */);
+						    const char *_Arguments /* [in] [charset(UTF16),unique] */);
 NTSTATUS dcerpc_svcctl_StartServiceA_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
 					  WERROR *result);
@@ -784,7 +784,7 @@ NTSTATUS dcerpc_svcctl_StartServiceA(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     struct policy_handle *_handle /* [in] [ref] */,
 				     uint32_t _NumArgs /* [in]  */,
-				     const char *_Arguments /* [in] [unique,charset(UTF16)] */,
+				     const char *_Arguments /* [in] [charset(UTF16),unique] */,
 				     WERROR *result);
 
 struct tevent_req *dcerpc_svcctl_GetServiceDisplayNameA_r_send(TALLOC_CTX *mem_ctx,
@@ -797,7 +797,7 @@ struct tevent_req *dcerpc_svcctl_GetServiceDisplayNameA_send(TALLOC_CTX *mem_ctx
 							     struct tevent_context *ev,
 							     struct dcerpc_binding_handle *h,
 							     struct policy_handle *_handle /* [in] [ref] */,
-							     const char *_service_name /* [in] [charset(UTF16),unique] */,
+							     const char *_service_name /* [in] [unique,charset(UTF16)] */,
 							     const char **_display_name /* [out] [ref,charset(UTF16)] */,
 							     uint32_t *_display_name_length /* [in,out] [unique] */);
 NTSTATUS dcerpc_svcctl_GetServiceDisplayNameA_recv(struct tevent_req *req,
@@ -806,7 +806,7 @@ NTSTATUS dcerpc_svcctl_GetServiceDisplayNameA_recv(struct tevent_req *req,
 NTSTATUS dcerpc_svcctl_GetServiceDisplayNameA(struct dcerpc_binding_handle *h,
 					      TALLOC_CTX *mem_ctx,
 					      struct policy_handle *_handle /* [in] [ref] */,
-					      const char *_service_name /* [in] [charset(UTF16),unique] */,
+					      const char *_service_name /* [in] [unique,charset(UTF16)] */,
 					      const char **_display_name /* [out] [ref,charset(UTF16)] */,
 					      uint32_t *_display_name_length /* [in,out] [unique] */,
 					      WERROR *result);
@@ -821,8 +821,8 @@ struct tevent_req *dcerpc_svcctl_GetServiceKeyNameA_send(TALLOC_CTX *mem_ctx,
 							 struct tevent_context *ev,
 							 struct dcerpc_binding_handle *h,
 							 struct policy_handle *_handle /* [in] [ref] */,
-							 const char *_service_name /* [in] [unique,charset(UTF16)] */,
-							 const char **_key_name /* [out] [charset(UTF16),ref] */,
+							 const char *_service_name /* [in] [charset(UTF16),unique] */,
+							 const char **_key_name /* [out] [ref,charset(UTF16)] */,
 							 uint32_t *_display_name_length /* [in,out] [unique] */);
 NTSTATUS dcerpc_svcctl_GetServiceKeyNameA_recv(struct tevent_req *req,
 					       TALLOC_CTX *mem_ctx,
@@ -830,8 +830,8 @@ NTSTATUS dcerpc_svcctl_GetServiceKeyNameA_recv(struct tevent_req *req,
 NTSTATUS dcerpc_svcctl_GetServiceKeyNameA(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
 					  struct policy_handle *_handle /* [in] [ref] */,
-					  const char *_service_name /* [in] [unique,charset(UTF16)] */,
-					  const char **_key_name /* [out] [charset(UTF16),ref] */,
+					  const char *_service_name /* [in] [charset(UTF16),unique] */,
+					  const char **_key_name /* [out] [ref,charset(UTF16)] */,
 					  uint32_t *_display_name_length /* [in,out] [unique] */,
 					  WERROR *result);
 
@@ -916,9 +916,9 @@ struct tevent_req *dcerpc_svcctl_QueryServiceConfig2W_send(TALLOC_CTX *mem_ctx,
 							   struct dcerpc_binding_handle *h,
 							   struct policy_handle *_handle /* [in] [ref] */,
 							   enum svcctl_ConfigLevel _info_level /* [in]  */,
-							   uint8_t *_buffer /* [out] [size_is(offered),ref] */,
+							   uint8_t *_buffer /* [out] [ref,size_is(offered)] */,
 							   uint32_t _offered /* [in] [range(0,8192)] */,
-							   uint32_t *_needed /* [out] [range(0,8192),ref] */);
+							   uint32_t *_needed /* [out] [ref,range(0,8192)] */);
 NTSTATUS dcerpc_svcctl_QueryServiceConfig2W_recv(struct tevent_req *req,
 						 TALLOC_CTX *mem_ctx,
 						 WERROR *result);
@@ -926,9 +926,9 @@ NTSTATUS dcerpc_svcctl_QueryServiceConfig2W(struct dcerpc_binding_handle *h,
 					    TALLOC_CTX *mem_ctx,
 					    struct policy_handle *_handle /* [in] [ref] */,
 					    enum svcctl_ConfigLevel _info_level /* [in]  */,
-					    uint8_t *_buffer /* [out] [size_is(offered),ref] */,
+					    uint8_t *_buffer /* [out] [ref,size_is(offered)] */,
 					    uint32_t _offered /* [in] [range(0,8192)] */,
-					    uint32_t *_needed /* [out] [range(0,8192),ref] */,
+					    uint32_t *_needed /* [out] [ref,range(0,8192)] */,
 					    WERROR *result);
 
 struct tevent_req *dcerpc_svcctl_QueryServiceStatusEx_r_send(TALLOC_CTX *mem_ctx,
@@ -942,7 +942,7 @@ struct tevent_req *dcerpc_svcctl_QueryServiceStatusEx_send(TALLOC_CTX *mem_ctx,
 							   struct dcerpc_binding_handle *h,
 							   struct policy_handle *_handle /* [in] [ref] */,
 							   enum svcctl_StatusLevel _info_level /* [in]  */,
-							   uint8_t *_buffer /* [out] [size_is(offered),ref] */,
+							   uint8_t *_buffer /* [out] [ref,size_is(offered)] */,
 							   uint32_t _offered /* [in] [range(0,8192)] */,
 							   uint32_t *_needed /* [out] [ref,range(0,8192)] */);
 NTSTATUS dcerpc_svcctl_QueryServiceStatusEx_recv(struct tevent_req *req,
@@ -952,7 +952,7 @@ NTSTATUS dcerpc_svcctl_QueryServiceStatusEx(struct dcerpc_binding_handle *h,
 					    TALLOC_CTX *mem_ctx,
 					    struct policy_handle *_handle /* [in] [ref] */,
 					    enum svcctl_StatusLevel _info_level /* [in]  */,
-					    uint8_t *_buffer /* [out] [size_is(offered),ref] */,
+					    uint8_t *_buffer /* [out] [ref,size_is(offered)] */,
 					    uint32_t _offered /* [in] [range(0,8192)] */,
 					    uint32_t *_needed /* [out] [ref,range(0,8192)] */,
 					    WERROR *result);
@@ -1006,7 +1006,7 @@ struct tevent_req *dcerpc_EnumServicesStatusExW_send(TALLOC_CTX *mem_ctx,
 						     uint32_t _info_level /* [in]  */,
 						     uint32_t _type /* [in]  */,
 						     enum svcctl_ServiceState _state /* [in]  */,
-						     uint8_t *_services /* [out] [ref,size_is(offered)] */,
+						     uint8_t *_services /* [out] [size_is(offered),ref] */,
 						     uint32_t _offered /* [in] [range(0,0x40000)] */,
 						     uint32_t *_needed /* [out] [range(0,0x40000),ref] */,
 						     uint32_t *_service_returned /* [out] [range(0,0x40000),ref] */,
@@ -1021,7 +1021,7 @@ NTSTATUS dcerpc_EnumServicesStatusExW(struct dcerpc_binding_handle *h,
 				      uint32_t _info_level /* [in]  */,
 				      uint32_t _type /* [in]  */,
 				      enum svcctl_ServiceState _state /* [in]  */,
-				      uint8_t *_services /* [out] [ref,size_is(offered)] */,
+				      uint8_t *_services /* [out] [size_is(offered),ref] */,
 				      uint32_t _offered /* [in] [range(0,0x40000)] */,
 				      uint32_t *_needed /* [out] [range(0,0x40000),ref] */,
 				      uint32_t *_service_returned /* [out] [range(0,0x40000),ref] */,
