@@ -35,7 +35,7 @@ struct tevent_req *dcerpc_wbint_LookupSid_send(TALLOC_CTX *mem_ctx,
 					       struct dom_sid *_sid /* [in] [ref] */,
 					       enum lsa_SidType *_type /* [out] [ref] */,
 					       const char **_domain /* [out] [charset(UTF8),ref] */,
-					       const char **_name /* [out] [ref,charset(UTF8)] */);
+					       const char **_name /* [out] [charset(UTF8),ref] */);
 NTSTATUS dcerpc_wbint_LookupSid_recv(struct tevent_req *req,
 				     TALLOC_CTX *mem_ctx,
 				     NTSTATUS *result);
@@ -44,7 +44,7 @@ NTSTATUS dcerpc_wbint_LookupSid(struct dcerpc_binding_handle *h,
 				struct dom_sid *_sid /* [in] [ref] */,
 				enum lsa_SidType *_type /* [out] [ref] */,
 				const char **_domain /* [out] [charset(UTF8),ref] */,
-				const char **_name /* [out] [ref,charset(UTF8)] */,
+				const char **_name /* [out] [charset(UTF8),ref] */,
 				NTSTATUS *result);
 
 struct tevent_req *dcerpc_wbint_LookupSids_r_send(TALLOC_CTX *mem_ctx,
@@ -78,7 +78,7 @@ NTSTATUS dcerpc_wbint_LookupName_r(struct dcerpc_binding_handle *h, TALLOC_CTX *
 struct tevent_req *dcerpc_wbint_LookupName_send(TALLOC_CTX *mem_ctx,
 						struct tevent_context *ev,
 						struct dcerpc_binding_handle *h,
-						const char *_domain /* [in] [charset(UTF8),ref] */,
+						const char *_domain /* [in] [ref,charset(UTF8)] */,
 						const char *_name /* [in] [ref,charset(UTF8)] */,
 						uint32_t _flags /* [in]  */,
 						enum lsa_SidType *_type /* [out] [ref] */,
@@ -88,7 +88,7 @@ NTSTATUS dcerpc_wbint_LookupName_recv(struct tevent_req *req,
 				      NTSTATUS *result);
 NTSTATUS dcerpc_wbint_LookupName(struct dcerpc_binding_handle *h,
 				 TALLOC_CTX *mem_ctx,
-				 const char *_domain /* [in] [charset(UTF8),ref] */,
+				 const char *_domain /* [in] [ref,charset(UTF8)] */,
 				 const char *_name /* [in] [ref,charset(UTF8)] */,
 				 uint32_t _flags /* [in]  */,
 				 enum lsa_SidType *_type /* [out] [ref] */,
@@ -124,7 +124,7 @@ NTSTATUS dcerpc_wbint_Uid2Sid_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem
 struct tevent_req *dcerpc_wbint_Uid2Sid_send(TALLOC_CTX *mem_ctx,
 					     struct tevent_context *ev,
 					     struct dcerpc_binding_handle *h,
-					     const char *_dom_name /* [in] [unique,charset(UTF8)] */,
+					     const char *_dom_name /* [in] [charset(UTF8),unique] */,
 					     uint64_t _uid /* [in]  */,
 					     struct dom_sid *_sid /* [out] [ref] */);
 NTSTATUS dcerpc_wbint_Uid2Sid_recv(struct tevent_req *req,
@@ -132,7 +132,7 @@ NTSTATUS dcerpc_wbint_Uid2Sid_recv(struct tevent_req *req,
 				   NTSTATUS *result);
 NTSTATUS dcerpc_wbint_Uid2Sid(struct dcerpc_binding_handle *h,
 			      TALLOC_CTX *mem_ctx,
-			      const char *_dom_name /* [in] [unique,charset(UTF8)] */,
+			      const char *_dom_name /* [in] [charset(UTF8),unique] */,
 			      uint64_t _uid /* [in]  */,
 			      struct dom_sid *_sid /* [out] [ref] */,
 			      NTSTATUS *result);
@@ -146,7 +146,7 @@ NTSTATUS dcerpc_wbint_Gid2Sid_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem
 struct tevent_req *dcerpc_wbint_Gid2Sid_send(TALLOC_CTX *mem_ctx,
 					     struct tevent_context *ev,
 					     struct dcerpc_binding_handle *h,
-					     const char *_dom_name /* [in] [unique,charset(UTF8)] */,
+					     const char *_dom_name /* [in] [charset(UTF8),unique] */,
 					     uint64_t _gid /* [in]  */,
 					     struct dom_sid *_sid /* [out] [ref] */);
 NTSTATUS dcerpc_wbint_Gid2Sid_recv(struct tevent_req *req,
@@ -154,7 +154,7 @@ NTSTATUS dcerpc_wbint_Gid2Sid_recv(struct tevent_req *req,
 				   NTSTATUS *result);
 NTSTATUS dcerpc_wbint_Gid2Sid(struct dcerpc_binding_handle *h,
 			      TALLOC_CTX *mem_ctx,
-			      const char *_dom_name /* [in] [unique,charset(UTF8)] */,
+			      const char *_dom_name /* [in] [charset(UTF8),unique] */,
 			      uint64_t _gid /* [in]  */,
 			      struct dom_sid *_sid /* [out] [ref] */,
 			      NTSTATUS *result);
@@ -340,7 +340,7 @@ NTSTATUS dcerpc_wbint_DsGetDcName_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_wbint_DsGetDcName_send(TALLOC_CTX *mem_ctx,
 						 struct tevent_context *ev,
 						 struct dcerpc_binding_handle *h,
-						 const char *_domain_name /* [in] [ref,charset(UTF8)] */,
+						 const char *_domain_name /* [in] [charset(UTF8),ref] */,
 						 struct GUID *_domain_guid /* [in] [unique] */,
 						 const char *_site_name /* [in] [unique,charset(UTF8)] */,
 						 uint32_t _flags /* [in]  */,
@@ -350,7 +350,7 @@ NTSTATUS dcerpc_wbint_DsGetDcName_recv(struct tevent_req *req,
 				       NTSTATUS *result);
 NTSTATUS dcerpc_wbint_DsGetDcName(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
-				  const char *_domain_name /* [in] [ref,charset(UTF8)] */,
+				  const char *_domain_name /* [in] [charset(UTF8),ref] */,
 				  struct GUID *_domain_guid /* [in] [unique] */,
 				  const char *_site_name /* [in] [unique,charset(UTF8)] */,
 				  uint32_t _flags /* [in]  */,
@@ -422,13 +422,13 @@ NTSTATUS dcerpc_wbint_PingDc_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem_
 struct tevent_req *dcerpc_wbint_PingDc_send(TALLOC_CTX *mem_ctx,
 					    struct tevent_context *ev,
 					    struct dcerpc_binding_handle *h,
-					    const char **_dcname /* [out] [ref,charset(UTF8)] */);
+					    const char **_dcname /* [out] [charset(UTF8),ref] */);
 NTSTATUS dcerpc_wbint_PingDc_recv(struct tevent_req *req,
 				  TALLOC_CTX *mem_ctx,
 				  NTSTATUS *result);
 NTSTATUS dcerpc_wbint_PingDc(struct dcerpc_binding_handle *h,
 			     TALLOC_CTX *mem_ctx,
-			     const char **_dcname /* [out] [ref,charset(UTF8)] */,
+			     const char **_dcname /* [out] [charset(UTF8),ref] */,
 			     NTSTATUS *result);
 
 #endif /* _HEADER_RPC_wbint */
