@@ -244,7 +244,7 @@ struct tevent_req *dcerpc_winreg_EnumValue_send(TALLOC_CTX *mem_ctx,
 						uint32_t _enum_index /* [in]  */,
 						struct winreg_ValNameBuf *_name /* [in,out] [ref] */,
 						enum winreg_Type *_type /* [in,out] [unique] */,
-						uint8_t *_value /* [in,out] [size_is(size?*size:0),unique,range(0,0x4000000),length_is(length?*length:0)] */,
+						uint8_t *_value /* [in,out] [length_is(length?*length:0),size_is(size?*size:0),range(0,0x4000000),unique] */,
 						uint32_t *_size /* [in,out] [unique] */,
 						uint32_t *_length /* [in,out] [unique] */);
 NTSTATUS dcerpc_winreg_EnumValue_recv(struct tevent_req *req,
@@ -256,7 +256,7 @@ NTSTATUS dcerpc_winreg_EnumValue(struct dcerpc_binding_handle *h,
 				 uint32_t _enum_index /* [in]  */,
 				 struct winreg_ValNameBuf *_name /* [in,out] [ref] */,
 				 enum winreg_Type *_type /* [in,out] [unique] */,
-				 uint8_t *_value /* [in,out] [size_is(size?*size:0),unique,range(0,0x4000000),length_is(length?*length:0)] */,
+				 uint8_t *_value /* [in,out] [length_is(length?*length:0),size_is(size?*size:0),range(0,0x4000000),unique] */,
 				 uint32_t *_size /* [in,out] [unique] */,
 				 uint32_t *_length /* [in,out] [unique] */,
 				 WERROR *result);
@@ -427,7 +427,7 @@ struct tevent_req *dcerpc_winreg_QueryValue_send(TALLOC_CTX *mem_ctx,
 						 struct policy_handle *_handle /* [in] [ref] */,
 						 struct winreg_String *_value_name /* [in] [ref] */,
 						 enum winreg_Type *_type /* [in,out] [unique] */,
-						 uint8_t *_data /* [in,out] [size_is(data_size?*data_size:0),range(0,0x4000000),unique,length_is(data_length?*data_length:0)] */,
+						 uint8_t *_data /* [in,out] [size_is(data_size?*data_size:0),length_is(data_length?*data_length:0),unique,range(0,0x4000000)] */,
 						 uint32_t *_data_size /* [in,out] [unique] */,
 						 uint32_t *_data_length /* [in,out] [unique] */);
 NTSTATUS dcerpc_winreg_QueryValue_recv(struct tevent_req *req,
@@ -438,7 +438,7 @@ NTSTATUS dcerpc_winreg_QueryValue(struct dcerpc_binding_handle *h,
 				  struct policy_handle *_handle /* [in] [ref] */,
 				  struct winreg_String *_value_name /* [in] [ref] */,
 				  enum winreg_Type *_type /* [in,out] [unique] */,
-				  uint8_t *_data /* [in,out] [size_is(data_size?*data_size:0),range(0,0x4000000),unique,length_is(data_length?*data_length:0)] */,
+				  uint8_t *_data /* [in,out] [size_is(data_size?*data_size:0),length_is(data_length?*data_length:0),unique,range(0,0x4000000)] */,
 				  uint32_t *_data_size /* [in,out] [unique] */,
 				  uint32_t *_data_length /* [in,out] [unique] */,
 				  WERROR *result);
@@ -545,7 +545,7 @@ struct tevent_req *dcerpc_winreg_SetValue_send(TALLOC_CTX *mem_ctx,
 					       struct policy_handle *_handle /* [in] [ref] */,
 					       struct winreg_String _name /* [in]  */,
 					       enum winreg_Type _type /* [in]  */,
-					       uint8_t *_data /* [in] [size_is(size),ref] */,
+					       uint8_t *_data /* [in] [ref,size_is(size)] */,
 					       uint32_t _size /* [in]  */);
 NTSTATUS dcerpc_winreg_SetValue_recv(struct tevent_req *req,
 				     TALLOC_CTX *mem_ctx,
@@ -555,7 +555,7 @@ NTSTATUS dcerpc_winreg_SetValue(struct dcerpc_binding_handle *h,
 				struct policy_handle *_handle /* [in] [ref] */,
 				struct winreg_String _name /* [in]  */,
 				enum winreg_Type _type /* [in]  */,
-				uint8_t *_data /* [in] [size_is(size),ref] */,
+				uint8_t *_data /* [in] [ref,size_is(size)] */,
 				uint32_t _size /* [in]  */,
 				WERROR *result);
 
@@ -697,10 +697,10 @@ struct tevent_req *dcerpc_winreg_QueryMultipleValues_send(TALLOC_CTX *mem_ctx,
 							  struct tevent_context *ev,
 							  struct dcerpc_binding_handle *h,
 							  struct policy_handle *_key_handle /* [in] [ref] */,
-							  struct QueryMultipleValue *_values_in /* [in] [length_is(num_values),ref,size_is(num_values)] */,
-							  struct QueryMultipleValue *_values_out /* [out] [length_is(num_values),size_is(num_values),ref] */,
+							  struct QueryMultipleValue *_values_in /* [in] [length_is(num_values),size_is(num_values),ref] */,
+							  struct QueryMultipleValue *_values_out /* [out] [size_is(num_values),ref,length_is(num_values)] */,
 							  uint32_t _num_values /* [in]  */,
-							  uint8_t *_buffer /* [in,out] [length_is(*buffer_size),unique,size_is(*buffer_size)] */,
+							  uint8_t *_buffer /* [in,out] [size_is(*buffer_size),length_is(*buffer_size),unique] */,
 							  uint32_t *_buffer_size /* [in,out] [ref] */);
 NTSTATUS dcerpc_winreg_QueryMultipleValues_recv(struct tevent_req *req,
 						TALLOC_CTX *mem_ctx,
@@ -708,10 +708,10 @@ NTSTATUS dcerpc_winreg_QueryMultipleValues_recv(struct tevent_req *req,
 NTSTATUS dcerpc_winreg_QueryMultipleValues(struct dcerpc_binding_handle *h,
 					   TALLOC_CTX *mem_ctx,
 					   struct policy_handle *_key_handle /* [in] [ref] */,
-					   struct QueryMultipleValue *_values_in /* [in] [length_is(num_values),ref,size_is(num_values)] */,
-					   struct QueryMultipleValue *_values_out /* [out] [length_is(num_values),size_is(num_values),ref] */,
+					   struct QueryMultipleValue *_values_in /* [in] [length_is(num_values),size_is(num_values),ref] */,
+					   struct QueryMultipleValue *_values_out /* [out] [size_is(num_values),ref,length_is(num_values)] */,
 					   uint32_t _num_values /* [in]  */,
-					   uint8_t *_buffer /* [in,out] [length_is(*buffer_size),unique,size_is(*buffer_size)] */,
+					   uint8_t *_buffer /* [in,out] [size_is(*buffer_size),length_is(*buffer_size),unique] */,
 					   uint32_t *_buffer_size /* [in,out] [ref] */,
 					   WERROR *result);
 
@@ -821,10 +821,10 @@ struct tevent_req *dcerpc_winreg_QueryMultipleValues2_send(TALLOC_CTX *mem_ctx,
 							   struct tevent_context *ev,
 							   struct dcerpc_binding_handle *h,
 							   struct policy_handle *_key_handle /* [in] [ref] */,
-							   struct QueryMultipleValue *_values_in /* [in] [ref,size_is(num_values),length_is(num_values)] */,
+							   struct QueryMultipleValue *_values_in /* [in] [length_is(num_values),ref,size_is(num_values)] */,
 							   struct QueryMultipleValue *_values_out /* [out] [size_is(num_values),ref,length_is(num_values)] */,
 							   uint32_t _num_values /* [in]  */,
-							   uint8_t *_buffer /* [in,out] [size_is(*offered),unique,length_is(*offered)] */,
+							   uint8_t *_buffer /* [in,out] [unique,length_is(*offered),size_is(*offered)] */,
 							   uint32_t *_offered /* [in] [ref] */,
 							   uint32_t *_needed /* [out] [ref] */);
 NTSTATUS dcerpc_winreg_QueryMultipleValues2_recv(struct tevent_req *req,
@@ -833,10 +833,10 @@ NTSTATUS dcerpc_winreg_QueryMultipleValues2_recv(struct tevent_req *req,
 NTSTATUS dcerpc_winreg_QueryMultipleValues2(struct dcerpc_binding_handle *h,
 					    TALLOC_CTX *mem_ctx,
 					    struct policy_handle *_key_handle /* [in] [ref] */,
-					    struct QueryMultipleValue *_values_in /* [in] [ref,size_is(num_values),length_is(num_values)] */,
+					    struct QueryMultipleValue *_values_in /* [in] [length_is(num_values),ref,size_is(num_values)] */,
 					    struct QueryMultipleValue *_values_out /* [out] [size_is(num_values),ref,length_is(num_values)] */,
 					    uint32_t _num_values /* [in]  */,
-					    uint8_t *_buffer /* [in,out] [size_is(*offered),unique,length_is(*offered)] */,
+					    uint8_t *_buffer /* [in,out] [unique,length_is(*offered),size_is(*offered)] */,
 					    uint32_t *_offered /* [in] [ref] */,
 					    uint32_t *_needed /* [out] [ref] */,
 					    WERROR *result);
