@@ -14,17 +14,17 @@ NTSTATUS dcerpc_wkssvc_NetWkstaGetInfo_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_wkssvc_NetWkstaGetInfo_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_server_name /* [in] [charset(UTF16),unique] */,
+						      const char *_server_name /* [in] [unique,charset(UTF16)] */,
 						      uint32_t _level /* [in]  */,
-						      union wkssvc_NetWkstaInfo *_info /* [out] [switch_is(level),ref] */);
+						      union wkssvc_NetWkstaInfo *_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_wkssvc_NetWkstaGetInfo_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetWkstaGetInfo(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_server_name /* [in] [charset(UTF16),unique] */,
+				       const char *_server_name /* [in] [unique,charset(UTF16)] */,
 				       uint32_t _level /* [in]  */,
-				       union wkssvc_NetWkstaInfo *_info /* [out] [switch_is(level),ref] */,
+				       union wkssvc_NetWkstaInfo *_info /* [out] [ref,switch_is(level)] */,
 				       WERROR *result);
 
 struct tevent_req *dcerpc_wkssvc_NetWkstaSetInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -38,7 +38,7 @@ struct tevent_req *dcerpc_wkssvc_NetWkstaSetInfo_send(TALLOC_CTX *mem_ctx,
 						      struct dcerpc_binding_handle *h,
 						      const char *_server_name /* [in] [unique,charset(UTF16)] */,
 						      uint32_t _level /* [in]  */,
-						      union wkssvc_NetWkstaInfo *_info /* [in] [switch_is(level),ref] */,
+						      union wkssvc_NetWkstaInfo *_info /* [in] [ref,switch_is(level)] */,
 						      uint32_t *_parm_error /* [in,out] [ref] */);
 NTSTATUS dcerpc_wkssvc_NetWkstaSetInfo_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
@@ -47,7 +47,7 @@ NTSTATUS dcerpc_wkssvc_NetWkstaSetInfo(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
 				       const char *_server_name /* [in] [unique,charset(UTF16)] */,
 				       uint32_t _level /* [in]  */,
-				       union wkssvc_NetWkstaInfo *_info /* [in] [switch_is(level),ref] */,
+				       union wkssvc_NetWkstaInfo *_info /* [in] [ref,switch_is(level)] */,
 				       uint32_t *_parm_error /* [in,out] [ref] */,
 				       WERROR *result);
 
@@ -60,7 +60,7 @@ NTSTATUS dcerpc_wkssvc_NetWkstaEnumUsers_r(struct dcerpc_binding_handle *h, TALL
 struct tevent_req *dcerpc_wkssvc_NetWkstaEnumUsers_send(TALLOC_CTX *mem_ctx,
 							struct tevent_context *ev,
 							struct dcerpc_binding_handle *h,
-							const char *_server_name /* [in] [charset(UTF16),unique] */,
+							const char *_server_name /* [in] [unique,charset(UTF16)] */,
 							struct wkssvc_NetWkstaEnumUsersInfo *_info /* [in,out] [ref] */,
 							uint32_t _prefmaxlen /* [in]  */,
 							uint32_t *_entries_read /* [out] [ref] */,
@@ -70,7 +70,7 @@ NTSTATUS dcerpc_wkssvc_NetWkstaEnumUsers_recv(struct tevent_req *req,
 					      WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetWkstaEnumUsers(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
-					 const char *_server_name /* [in] [charset(UTF16),unique] */,
+					 const char *_server_name /* [in] [unique,charset(UTF16)] */,
 					 struct wkssvc_NetWkstaEnumUsersInfo *_info /* [in,out] [ref] */,
 					 uint32_t _prefmaxlen /* [in]  */,
 					 uint32_t *_entries_read /* [out] [ref] */,
@@ -86,17 +86,17 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaUserGetInfo_r(struct dcerpc_binding_handle *h, T
 struct tevent_req *dcerpc_wkssvc_NetrWkstaUserGetInfo_send(TALLOC_CTX *mem_ctx,
 							   struct tevent_context *ev,
 							   struct dcerpc_binding_handle *h,
-							   const char *_unknown /* [in] [charset(UTF16),unique] */,
+							   const char *_unknown /* [in] [unique,charset(UTF16)] */,
 							   uint32_t _level /* [in]  */,
-							   union wkssvc_NetrWkstaUserInfo *_info /* [out] [ref,switch_is(level)] */);
+							   union wkssvc_NetrWkstaUserInfo *_info /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_wkssvc_NetrWkstaUserGetInfo_recv(struct tevent_req *req,
 						 TALLOC_CTX *mem_ctx,
 						 WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrWkstaUserGetInfo(struct dcerpc_binding_handle *h,
 					    TALLOC_CTX *mem_ctx,
-					    const char *_unknown /* [in] [charset(UTF16),unique] */,
+					    const char *_unknown /* [in] [unique,charset(UTF16)] */,
 					    uint32_t _level /* [in]  */,
-					    union wkssvc_NetrWkstaUserInfo *_info /* [out] [ref,switch_is(level)] */,
+					    union wkssvc_NetrWkstaUserInfo *_info /* [out] [switch_is(level),ref] */,
 					    WERROR *result);
 
 struct tevent_req *dcerpc_wkssvc_NetrWkstaUserSetInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -108,7 +108,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaUserSetInfo_r(struct dcerpc_binding_handle *h, T
 struct tevent_req *dcerpc_wkssvc_NetrWkstaUserSetInfo_send(TALLOC_CTX *mem_ctx,
 							   struct tevent_context *ev,
 							   struct dcerpc_binding_handle *h,
-							   const char *_unknown /* [in] [unique,charset(UTF16)] */,
+							   const char *_unknown /* [in] [charset(UTF16),unique] */,
 							   uint32_t _level /* [in]  */,
 							   union wkssvc_NetrWkstaUserInfo *_info /* [in] [ref,switch_is(level)] */,
 							   uint32_t *_parm_err /* [in,out] [unique] */);
@@ -117,7 +117,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaUserSetInfo_recv(struct tevent_req *req,
 						 WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrWkstaUserSetInfo(struct dcerpc_binding_handle *h,
 					    TALLOC_CTX *mem_ctx,
-					    const char *_unknown /* [in] [unique,charset(UTF16)] */,
+					    const char *_unknown /* [in] [charset(UTF16),unique] */,
 					    uint32_t _level /* [in]  */,
 					    union wkssvc_NetrWkstaUserInfo *_info /* [in] [ref,switch_is(level)] */,
 					    uint32_t *_parm_err /* [in,out] [unique] */,
@@ -132,7 +132,7 @@ NTSTATUS dcerpc_wkssvc_NetWkstaTransportEnum_r(struct dcerpc_binding_handle *h,
 struct tevent_req *dcerpc_wkssvc_NetWkstaTransportEnum_send(TALLOC_CTX *mem_ctx,
 							    struct tevent_context *ev,
 							    struct dcerpc_binding_handle *h,
-							    const char *_server_name /* [in] [charset(UTF16),unique] */,
+							    const char *_server_name /* [in] [unique,charset(UTF16)] */,
 							    struct wkssvc_NetWkstaTransportInfo *_info /* [in,out] [ref] */,
 							    uint32_t _max_buffer /* [in]  */,
 							    uint32_t *_total_entries /* [out] [ref] */,
@@ -142,7 +142,7 @@ NTSTATUS dcerpc_wkssvc_NetWkstaTransportEnum_recv(struct tevent_req *req,
 						  WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetWkstaTransportEnum(struct dcerpc_binding_handle *h,
 					     TALLOC_CTX *mem_ctx,
-					     const char *_server_name /* [in] [charset(UTF16),unique] */,
+					     const char *_server_name /* [in] [unique,charset(UTF16)] */,
 					     struct wkssvc_NetWkstaTransportInfo *_info /* [in,out] [ref] */,
 					     uint32_t _max_buffer /* [in]  */,
 					     uint32_t *_total_entries /* [out] [ref] */,
@@ -158,7 +158,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaTransportAdd_r(struct dcerpc_binding_handle *h,
 struct tevent_req *dcerpc_wkssvc_NetrWkstaTransportAdd_send(TALLOC_CTX *mem_ctx,
 							    struct tevent_context *ev,
 							    struct dcerpc_binding_handle *h,
-							    const char *_server_name /* [in] [charset(UTF16),unique] */,
+							    const char *_server_name /* [in] [unique,charset(UTF16)] */,
 							    uint32_t _level /* [in]  */,
 							    struct wkssvc_NetWkstaTransportInfo0 *_info0 /* [in] [ref] */,
 							    uint32_t *_parm_err /* [in,out] [unique] */);
@@ -167,7 +167,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaTransportAdd_recv(struct tevent_req *req,
 						  WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrWkstaTransportAdd(struct dcerpc_binding_handle *h,
 					     TALLOC_CTX *mem_ctx,
-					     const char *_server_name /* [in] [charset(UTF16),unique] */,
+					     const char *_server_name /* [in] [unique,charset(UTF16)] */,
 					     uint32_t _level /* [in]  */,
 					     struct wkssvc_NetWkstaTransportInfo0 *_info0 /* [in] [ref] */,
 					     uint32_t *_parm_err /* [in,out] [unique] */,
@@ -183,7 +183,7 @@ struct tevent_req *dcerpc_wkssvc_NetrWkstaTransportDel_send(TALLOC_CTX *mem_ctx,
 							    struct tevent_context *ev,
 							    struct dcerpc_binding_handle *h,
 							    const char *_server_name /* [in] [unique,charset(UTF16)] */,
-							    const char *_transport_name /* [in] [charset(UTF16),unique] */,
+							    const char *_transport_name /* [in] [unique,charset(UTF16)] */,
 							    uint32_t _unknown3 /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrWkstaTransportDel_recv(struct tevent_req *req,
 						  TALLOC_CTX *mem_ctx,
@@ -191,7 +191,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaTransportDel_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrWkstaTransportDel(struct dcerpc_binding_handle *h,
 					     TALLOC_CTX *mem_ctx,
 					     const char *_server_name /* [in] [unique,charset(UTF16)] */,
-					     const char *_transport_name /* [in] [charset(UTF16),unique] */,
+					     const char *_transport_name /* [in] [unique,charset(UTF16)] */,
 					     uint32_t _unknown3 /* [in]  */,
 					     WERROR *result);
 
@@ -204,18 +204,18 @@ NTSTATUS dcerpc_wkssvc_NetrUseAdd_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_wkssvc_NetrUseAdd_send(TALLOC_CTX *mem_ctx,
 						 struct tevent_context *ev,
 						 struct dcerpc_binding_handle *h,
-						 const char *_server_name /* [in] [unique,charset(UTF16)] */,
+						 const char *_server_name /* [in] [charset(UTF16),unique] */,
 						 uint32_t _level /* [in]  */,
-						 union wkssvc_NetrUseGetInfoCtr *_ctr /* [in] [ref,switch_is(level)] */,
+						 union wkssvc_NetrUseGetInfoCtr *_ctr /* [in] [switch_is(level),ref] */,
 						 uint32_t *_parm_err /* [in,out] [unique] */);
 NTSTATUS dcerpc_wkssvc_NetrUseAdd_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
 				       WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrUseAdd(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
-				  const char *_server_name /* [in] [unique,charset(UTF16)] */,
+				  const char *_server_name /* [in] [charset(UTF16),unique] */,
 				  uint32_t _level /* [in]  */,
-				  union wkssvc_NetrUseGetInfoCtr *_ctr /* [in] [ref,switch_is(level)] */,
+				  union wkssvc_NetrUseGetInfoCtr *_ctr /* [in] [switch_is(level),ref] */,
 				  uint32_t *_parm_err /* [in,out] [unique] */,
 				  WERROR *result);
 
@@ -229,18 +229,18 @@ struct tevent_req *dcerpc_wkssvc_NetrUseGetInfo_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
 						     const char *_server_name /* [in] [charset(UTF16),unique] */,
-						     const char *_use_name /* [in] [charset(UTF16),ref] */,
+						     const char *_use_name /* [in] [ref,charset(UTF16)] */,
 						     uint32_t _level /* [in]  */,
-						     union wkssvc_NetrUseGetInfoCtr *_ctr /* [out] [ref,switch_is(level)] */);
+						     union wkssvc_NetrUseGetInfoCtr *_ctr /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_wkssvc_NetrUseGetInfo_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
 					   WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrUseGetInfo(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      const char *_server_name /* [in] [charset(UTF16),unique] */,
-				      const char *_use_name /* [in] [charset(UTF16),ref] */,
+				      const char *_use_name /* [in] [ref,charset(UTF16)] */,
 				      uint32_t _level /* [in]  */,
-				      union wkssvc_NetrUseGetInfoCtr *_ctr /* [out] [ref,switch_is(level)] */,
+				      union wkssvc_NetrUseGetInfoCtr *_ctr /* [out] [switch_is(level),ref] */,
 				      WERROR *result);
 
 struct tevent_req *dcerpc_wkssvc_NetrUseDel_r_send(TALLOC_CTX *mem_ctx,
@@ -301,8 +301,8 @@ struct tevent_req *dcerpc_wkssvc_NetrMessageBufferSend_send(TALLOC_CTX *mem_ctx,
 							    struct tevent_context *ev,
 							    struct dcerpc_binding_handle *h,
 							    const char *_server_name /* [in] [unique,charset(UTF16)] */,
-							    const char *_message_name /* [in] [ref,charset(UTF16)] */,
-							    const char *_message_sender_name /* [in] [unique,charset(UTF16)] */,
+							    const char *_message_name /* [in] [charset(UTF16),ref] */,
+							    const char *_message_sender_name /* [in] [charset(UTF16),unique] */,
 							    uint8_t *_message_buffer /* [in] [ref,size_is(message_size)] */,
 							    uint32_t _message_size /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrMessageBufferSend_recv(struct tevent_req *req,
@@ -311,8 +311,8 @@ NTSTATUS dcerpc_wkssvc_NetrMessageBufferSend_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrMessageBufferSend(struct dcerpc_binding_handle *h,
 					     TALLOC_CTX *mem_ctx,
 					     const char *_server_name /* [in] [unique,charset(UTF16)] */,
-					     const char *_message_name /* [in] [ref,charset(UTF16)] */,
-					     const char *_message_sender_name /* [in] [unique,charset(UTF16)] */,
+					     const char *_message_name /* [in] [charset(UTF16),ref] */,
+					     const char *_message_sender_name /* [in] [charset(UTF16),unique] */,
 					     uint8_t *_message_buffer /* [in] [ref,size_is(message_size)] */,
 					     uint32_t _message_size /* [in]  */,
 					     WERROR *result);
@@ -327,7 +327,7 @@ struct tevent_req *dcerpc_wkssvc_NetrWorkstationStatisticsGet_send(TALLOC_CTX *m
 								   struct tevent_context *ev,
 								   struct dcerpc_binding_handle *h,
 								   const char *_server_name /* [in] [unique,charset(UTF16)] */,
-								   const char *_unknown2 /* [in] [unique,charset(UTF16)] */,
+								   const char *_unknown2 /* [in] [charset(UTF16),unique] */,
 								   uint32_t _unknown3 /* [in]  */,
 								   uint32_t _unknown4 /* [in]  */,
 								   struct wkssvc_NetrWorkstationStatistics **_info /* [out] [ref] */);
@@ -337,7 +337,7 @@ NTSTATUS dcerpc_wkssvc_NetrWorkstationStatisticsGet_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrWorkstationStatisticsGet(struct dcerpc_binding_handle *h,
 						    TALLOC_CTX *mem_ctx,
 						    const char *_server_name /* [in] [unique,charset(UTF16)] */,
-						    const char *_unknown2 /* [in] [unique,charset(UTF16)] */,
+						    const char *_unknown2 /* [in] [charset(UTF16),unique] */,
 						    uint32_t _unknown3 /* [in]  */,
 						    uint32_t _unknown4 /* [in]  */,
 						    struct wkssvc_NetrWorkstationStatistics **_info /* [out] [ref] */,
@@ -390,9 +390,9 @@ struct tevent_req *dcerpc_wkssvc_NetrJoinDomain_send(TALLOC_CTX *mem_ctx,
 						     struct dcerpc_binding_handle *h,
 						     const char *_server_name /* [in] [unique,charset(UTF16)] */,
 						     const char *_domain_name /* [in] [charset(UTF16),ref] */,
-						     const char *_account_ou /* [in] [unique,charset(UTF16)] */,
+						     const char *_account_ou /* [in] [charset(UTF16),unique] */,
 						     const char *_Account /* [in] [unique,charset(UTF16)] */,
-						     const char *_password /* [in] [charset(UTF16),unique] */,
+						     const char *_password /* [in] [unique,charset(UTF16)] */,
 						     uint32_t _join_flags /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrJoinDomain_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
@@ -401,9 +401,9 @@ NTSTATUS dcerpc_wkssvc_NetrJoinDomain(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      const char *_server_name /* [in] [unique,charset(UTF16)] */,
 				      const char *_domain_name /* [in] [charset(UTF16),ref] */,
-				      const char *_account_ou /* [in] [unique,charset(UTF16)] */,
+				      const char *_account_ou /* [in] [charset(UTF16),unique] */,
 				      const char *_Account /* [in] [unique,charset(UTF16)] */,
-				      const char *_password /* [in] [charset(UTF16),unique] */,
+				      const char *_password /* [in] [unique,charset(UTF16)] */,
 				      uint32_t _join_flags /* [in]  */,
 				      WERROR *result);
 
@@ -416,8 +416,8 @@ NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain_r(struct dcerpc_binding_handle *h, TALLO
 struct tevent_req *dcerpc_wkssvc_NetrUnjoinDomain_send(TALLOC_CTX *mem_ctx,
 						       struct tevent_context *ev,
 						       struct dcerpc_binding_handle *h,
-						       const char *_server_name /* [in] [unique,charset(UTF16)] */,
-						       const char *_Account /* [in] [unique,charset(UTF16)] */,
+						       const char *_server_name /* [in] [charset(UTF16),unique] */,
+						       const char *_Account /* [in] [charset(UTF16),unique] */,
 						       const char *_password /* [in] [unique,charset(UTF16)] */,
 						       uint32_t _unjoin_flags /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain_recv(struct tevent_req *req,
@@ -425,8 +425,8 @@ NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain_recv(struct tevent_req *req,
 					     WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain(struct dcerpc_binding_handle *h,
 					TALLOC_CTX *mem_ctx,
-					const char *_server_name /* [in] [unique,charset(UTF16)] */,
-					const char *_Account /* [in] [unique,charset(UTF16)] */,
+					const char *_server_name /* [in] [charset(UTF16),unique] */,
+					const char *_Account /* [in] [charset(UTF16),unique] */,
 					const char *_password /* [in] [unique,charset(UTF16)] */,
 					uint32_t _unjoin_flags /* [in]  */,
 					WERROR *result);
@@ -441,7 +441,7 @@ struct tevent_req *dcerpc_wkssvc_NetrRenameMachineInDomain_send(TALLOC_CTX *mem_
 								struct tevent_context *ev,
 								struct dcerpc_binding_handle *h,
 								const char *_server_name /* [in] [charset(UTF16),unique] */,
-								const char *_NewMachineName /* [in] [unique,charset(UTF16)] */,
+								const char *_NewMachineName /* [in] [charset(UTF16),unique] */,
 								const char *_Account /* [in] [unique,charset(UTF16)] */,
 								const char *_password /* [in] [unique,charset(UTF16)] */,
 								uint32_t _RenameOptions /* [in]  */);
@@ -451,7 +451,7 @@ NTSTATUS dcerpc_wkssvc_NetrRenameMachineInDomain_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrRenameMachineInDomain(struct dcerpc_binding_handle *h,
 						 TALLOC_CTX *mem_ctx,
 						 const char *_server_name /* [in] [charset(UTF16),unique] */,
-						 const char *_NewMachineName /* [in] [unique,charset(UTF16)] */,
+						 const char *_NewMachineName /* [in] [charset(UTF16),unique] */,
 						 const char *_Account /* [in] [unique,charset(UTF16)] */,
 						 const char *_password /* [in] [unique,charset(UTF16)] */,
 						 uint32_t _RenameOptions /* [in]  */,
@@ -467,9 +467,9 @@ struct tevent_req *dcerpc_wkssvc_NetrValidateName_send(TALLOC_CTX *mem_ctx,
 						       struct tevent_context *ev,
 						       struct dcerpc_binding_handle *h,
 						       const char *_server_name /* [in] [unique,charset(UTF16)] */,
-						       const char *_name /* [in] [ref,charset(UTF16)] */,
-						       const char *_Account /* [in] [charset(UTF16),unique] */,
-						       const char *_Password /* [in] [charset(UTF16),unique] */,
+						       const char *_name /* [in] [charset(UTF16),ref] */,
+						       const char *_Account /* [in] [unique,charset(UTF16)] */,
+						       const char *_Password /* [in] [unique,charset(UTF16)] */,
 						       enum wkssvc_NetValidateNameType _name_type /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrValidateName_recv(struct tevent_req *req,
 					     TALLOC_CTX *mem_ctx,
@@ -477,9 +477,9 @@ NTSTATUS dcerpc_wkssvc_NetrValidateName_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrValidateName(struct dcerpc_binding_handle *h,
 					TALLOC_CTX *mem_ctx,
 					const char *_server_name /* [in] [unique,charset(UTF16)] */,
-					const char *_name /* [in] [ref,charset(UTF16)] */,
-					const char *_Account /* [in] [charset(UTF16),unique] */,
-					const char *_Password /* [in] [charset(UTF16),unique] */,
+					const char *_name /* [in] [charset(UTF16),ref] */,
+					const char *_Account /* [in] [unique,charset(UTF16)] */,
+					const char *_Password /* [in] [unique,charset(UTF16)] */,
 					enum wkssvc_NetValidateNameType _name_type /* [in]  */,
 					WERROR *result);
 
@@ -519,7 +519,7 @@ struct tevent_req *dcerpc_wkssvc_NetrGetJoinableOus_send(TALLOC_CTX *mem_ctx,
 							 const char *_Account /* [in] [unique,charset(UTF16)] */,
 							 const char *_unknown /* [in] [unique,charset(UTF16)] */,
 							 uint32_t *_num_ous /* [in,out] [ref] */,
-							 const char ***_ous /* [out] [ref,charset(UTF16),size_is(,*num_ous)] */);
+							 const char ***_ous /* [out] [ref,size_is(,*num_ous),charset(UTF16)] */);
 NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus_recv(struct tevent_req *req,
 					       TALLOC_CTX *mem_ctx,
 					       WERROR *result);
@@ -530,7 +530,7 @@ NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus(struct dcerpc_binding_handle *h,
 					  const char *_Account /* [in] [unique,charset(UTF16)] */,
 					  const char *_unknown /* [in] [unique,charset(UTF16)] */,
 					  uint32_t *_num_ous /* [in,out] [ref] */,
-					  const char ***_ous /* [out] [ref,charset(UTF16),size_is(,*num_ous)] */,
+					  const char ***_ous /* [out] [ref,size_is(,*num_ous),charset(UTF16)] */,
 					  WERROR *result);
 
 struct tevent_req *dcerpc_wkssvc_NetrJoinDomain2_r_send(TALLOC_CTX *mem_ctx,
@@ -544,8 +544,8 @@ struct tevent_req *dcerpc_wkssvc_NetrJoinDomain2_send(TALLOC_CTX *mem_ctx,
 						      struct dcerpc_binding_handle *h,
 						      const char *_server_name /* [in] [unique,charset(UTF16)] */,
 						      const char *_domain_name /* [in] [charset(UTF16),ref] */,
-						      const char *_account_ou /* [in] [charset(UTF16),unique] */,
-						      const char *_admin_account /* [in] [unique,charset(UTF16)] */,
+						      const char *_account_ou /* [in] [unique,charset(UTF16)] */,
+						      const char *_admin_account /* [in] [charset(UTF16),unique] */,
 						      struct wkssvc_PasswordBuffer *_encrypted_password /* [in] [unique] */,
 						      uint32_t _join_flags /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrJoinDomain2_recv(struct tevent_req *req,
@@ -555,8 +555,8 @@ NTSTATUS dcerpc_wkssvc_NetrJoinDomain2(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
 				       const char *_server_name /* [in] [unique,charset(UTF16)] */,
 				       const char *_domain_name /* [in] [charset(UTF16),ref] */,
-				       const char *_account_ou /* [in] [charset(UTF16),unique] */,
-				       const char *_admin_account /* [in] [unique,charset(UTF16)] */,
+				       const char *_account_ou /* [in] [unique,charset(UTF16)] */,
+				       const char *_admin_account /* [in] [charset(UTF16),unique] */,
 				       struct wkssvc_PasswordBuffer *_encrypted_password /* [in] [unique] */,
 				       uint32_t _join_flags /* [in]  */,
 				       WERROR *result);
@@ -570,8 +570,8 @@ NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain2_r(struct dcerpc_binding_handle *h, TALL
 struct tevent_req *dcerpc_wkssvc_NetrUnjoinDomain2_send(TALLOC_CTX *mem_ctx,
 							struct tevent_context *ev,
 							struct dcerpc_binding_handle *h,
-							const char *_server_name /* [in] [charset(UTF16),unique] */,
-							const char *_account /* [in] [unique,charset(UTF16)] */,
+							const char *_server_name /* [in] [unique,charset(UTF16)] */,
+							const char *_account /* [in] [charset(UTF16),unique] */,
 							struct wkssvc_PasswordBuffer *_encrypted_password /* [in] [unique] */,
 							uint32_t _unjoin_flags /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain2_recv(struct tevent_req *req,
@@ -579,8 +579,8 @@ NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain2_recv(struct tevent_req *req,
 					      WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain2(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
-					 const char *_server_name /* [in] [charset(UTF16),unique] */,
-					 const char *_account /* [in] [unique,charset(UTF16)] */,
+					 const char *_server_name /* [in] [unique,charset(UTF16)] */,
+					 const char *_account /* [in] [charset(UTF16),unique] */,
 					 struct wkssvc_PasswordBuffer *_encrypted_password /* [in] [unique] */,
 					 uint32_t _unjoin_flags /* [in]  */,
 					 WERROR *result);
@@ -622,7 +622,7 @@ struct tevent_req *dcerpc_wkssvc_NetrValidateName2_send(TALLOC_CTX *mem_ctx,
 							struct dcerpc_binding_handle *h,
 							const char *_server_name /* [in] [charset(UTF16),unique] */,
 							const char *_name /* [in] [charset(UTF16),ref] */,
-							const char *_Account /* [in] [charset(UTF16),unique] */,
+							const char *_Account /* [in] [unique,charset(UTF16)] */,
 							struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 							enum wkssvc_NetValidateNameType _name_type /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrValidateName2_recv(struct tevent_req *req,
@@ -632,7 +632,7 @@ NTSTATUS dcerpc_wkssvc_NetrValidateName2(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
 					 const char *_server_name /* [in] [charset(UTF16),unique] */,
 					 const char *_name /* [in] [charset(UTF16),ref] */,
-					 const char *_Account /* [in] [charset(UTF16),unique] */,
+					 const char *_Account /* [in] [unique,charset(UTF16)] */,
 					 struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 					 enum wkssvc_NetValidateNameType _name_type /* [in]  */,
 					 WERROR *result);
@@ -646,9 +646,9 @@ NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus2_r(struct dcerpc_binding_handle *h, TA
 struct tevent_req *dcerpc_wkssvc_NetrGetJoinableOus2_send(TALLOC_CTX *mem_ctx,
 							  struct tevent_context *ev,
 							  struct dcerpc_binding_handle *h,
-							  const char *_server_name /* [in] [unique,charset(UTF16)] */,
+							  const char *_server_name /* [in] [charset(UTF16),unique] */,
 							  const char *_domain_name /* [in] [charset(UTF16),ref] */,
-							  const char *_Account /* [in] [charset(UTF16),unique] */,
+							  const char *_Account /* [in] [unique,charset(UTF16)] */,
 							  struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 							  uint32_t *_num_ous /* [in,out] [ref] */,
 							  const char ***_ous /* [out] [size_is(,*num_ous),ref,charset(UTF16)] */);
@@ -657,9 +657,9 @@ NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus2_recv(struct tevent_req *req,
 						WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus2(struct dcerpc_binding_handle *h,
 					   TALLOC_CTX *mem_ctx,
-					   const char *_server_name /* [in] [unique,charset(UTF16)] */,
+					   const char *_server_name /* [in] [charset(UTF16),unique] */,
 					   const char *_domain_name /* [in] [charset(UTF16),ref] */,
-					   const char *_Account /* [in] [charset(UTF16),unique] */,
+					   const char *_Account /* [in] [unique,charset(UTF16)] */,
 					   struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 					   uint32_t *_num_ous /* [in,out] [ref] */,
 					   const char ***_ous /* [out] [size_is(,*num_ous),ref,charset(UTF16)] */,
@@ -674,9 +674,9 @@ NTSTATUS dcerpc_wkssvc_NetrAddAlternateComputerName_r(struct dcerpc_binding_hand
 struct tevent_req *dcerpc_wkssvc_NetrAddAlternateComputerName_send(TALLOC_CTX *mem_ctx,
 								   struct tevent_context *ev,
 								   struct dcerpc_binding_handle *h,
-								   const char *_server_name /* [in] [charset(UTF16),unique] */,
-								   const char *_NewAlternateMachineName /* [in] [charset(UTF16),unique] */,
-								   const char *_Account /* [in] [charset(UTF16),unique] */,
+								   const char *_server_name /* [in] [unique,charset(UTF16)] */,
+								   const char *_NewAlternateMachineName /* [in] [unique,charset(UTF16)] */,
+								   const char *_Account /* [in] [unique,charset(UTF16)] */,
 								   struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 								   uint32_t _Reserved /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrAddAlternateComputerName_recv(struct tevent_req *req,
@@ -684,9 +684,9 @@ NTSTATUS dcerpc_wkssvc_NetrAddAlternateComputerName_recv(struct tevent_req *req,
 							 WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrAddAlternateComputerName(struct dcerpc_binding_handle *h,
 						    TALLOC_CTX *mem_ctx,
-						    const char *_server_name /* [in] [charset(UTF16),unique] */,
-						    const char *_NewAlternateMachineName /* [in] [charset(UTF16),unique] */,
-						    const char *_Account /* [in] [charset(UTF16),unique] */,
+						    const char *_server_name /* [in] [unique,charset(UTF16)] */,
+						    const char *_NewAlternateMachineName /* [in] [unique,charset(UTF16)] */,
+						    const char *_Account /* [in] [unique,charset(UTF16)] */,
 						    struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 						    uint32_t _Reserved /* [in]  */,
 						    WERROR *result);
@@ -702,7 +702,7 @@ struct tevent_req *dcerpc_wkssvc_NetrRemoveAlternateComputerName_send(TALLOC_CTX
 								      struct dcerpc_binding_handle *h,
 								      const char *_server_name /* [in] [charset(UTF16),unique] */,
 								      const char *_AlternateMachineNameToRemove /* [in] [charset(UTF16),unique] */,
-								      const char *_Account /* [in] [charset(UTF16),unique] */,
+								      const char *_Account /* [in] [unique,charset(UTF16)] */,
 								      struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 								      uint32_t _Reserved /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrRemoveAlternateComputerName_recv(struct tevent_req *req,
@@ -712,7 +712,7 @@ NTSTATUS dcerpc_wkssvc_NetrRemoveAlternateComputerName(struct dcerpc_binding_han
 						       TALLOC_CTX *mem_ctx,
 						       const char *_server_name /* [in] [charset(UTF16),unique] */,
 						       const char *_AlternateMachineNameToRemove /* [in] [charset(UTF16),unique] */,
-						       const char *_Account /* [in] [charset(UTF16),unique] */,
+						       const char *_Account /* [in] [unique,charset(UTF16)] */,
 						       struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 						       uint32_t _Reserved /* [in]  */,
 						       WERROR *result);
@@ -727,7 +727,7 @@ struct tevent_req *dcerpc_wkssvc_NetrSetPrimaryComputername_send(TALLOC_CTX *mem
 								 struct tevent_context *ev,
 								 struct dcerpc_binding_handle *h,
 								 const char *_server_name /* [in] [charset(UTF16),unique] */,
-								 const char *_primary_name /* [in] [charset(UTF16),unique] */,
+								 const char *_primary_name /* [in] [unique,charset(UTF16)] */,
 								 const char *_Account /* [in] [charset(UTF16),unique] */,
 								 struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 								 uint32_t _Reserved /* [in]  */);
@@ -737,7 +737,7 @@ NTSTATUS dcerpc_wkssvc_NetrSetPrimaryComputername_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrSetPrimaryComputername(struct dcerpc_binding_handle *h,
 						  TALLOC_CTX *mem_ctx,
 						  const char *_server_name /* [in] [charset(UTF16),unique] */,
-						  const char *_primary_name /* [in] [charset(UTF16),unique] */,
+						  const char *_primary_name /* [in] [unique,charset(UTF16)] */,
 						  const char *_Account /* [in] [charset(UTF16),unique] */,
 						  struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 						  uint32_t _Reserved /* [in]  */,
@@ -752,7 +752,7 @@ NTSTATUS dcerpc_wkssvc_NetrEnumerateComputerNames_r(struct dcerpc_binding_handle
 struct tevent_req *dcerpc_wkssvc_NetrEnumerateComputerNames_send(TALLOC_CTX *mem_ctx,
 								 struct tevent_context *ev,
 								 struct dcerpc_binding_handle *h,
-								 const char *_server_name /* [in] [charset(UTF16),unique] */,
+								 const char *_server_name /* [in] [unique,charset(UTF16)] */,
 								 enum wkssvc_ComputerNameType _name_type /* [in]  */,
 								 uint32_t _Reserved /* [in]  */,
 								 struct wkssvc_ComputerNamesCtr **_ctr /* [out] [ref] */);
@@ -761,7 +761,7 @@ NTSTATUS dcerpc_wkssvc_NetrEnumerateComputerNames_recv(struct tevent_req *req,
 						       WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrEnumerateComputerNames(struct dcerpc_binding_handle *h,
 						  TALLOC_CTX *mem_ctx,
-						  const char *_server_name /* [in] [charset(UTF16),unique] */,
+						  const char *_server_name /* [in] [unique,charset(UTF16)] */,
 						  enum wkssvc_ComputerNameType _name_type /* [in]  */,
 						  uint32_t _Reserved /* [in]  */,
 						  struct wkssvc_ComputerNamesCtr **_ctr /* [out] [ref] */,
