@@ -16,7 +16,7 @@ struct tevent_req *dcerpc_Delete_send(TALLOC_CTX *mem_ctx,
 				      struct dcerpc_binding_handle *h,
 				      struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 				      struct ORPCTHIS _ORPCthis /* [in]  */,
-				      const char *_wszName /* [in] [charset(UTF16),ref] */);
+				      const char *_wszName /* [in] [ref,charset(UTF16)] */);
 NTSTATUS dcerpc_Delete_recv(struct tevent_req *req,
 			    TALLOC_CTX *mem_ctx,
 			    WERROR *result);
@@ -24,7 +24,7 @@ NTSTATUS dcerpc_Delete(struct dcerpc_binding_handle *h,
 		       TALLOC_CTX *mem_ctx,
 		       struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 		       struct ORPCTHIS _ORPCthis /* [in]  */,
-		       const char *_wszName /* [in] [charset(UTF16),ref] */,
+		       const char *_wszName /* [in] [ref,charset(UTF16)] */,
 		       WERROR *result);
 
 #endif /* _HEADER_RPC_IWbemClassObject */
@@ -728,7 +728,7 @@ struct tevent_req *dcerpc_IEnumWbemClassObject_Next_send(TALLOC_CTX *mem_ctx,
 							 struct ORPCTHIS _ORPCthis /* [in]  */,
 							 int32_t _lTimeout /* [in]  */,
 							 uint32_t _uCount /* [in]  */,
-							 struct MInterfacePointer **_apObjects /* [out] [ref,size_is(uCount),length_is(*puReturned)] */,
+							 struct MInterfacePointer **_apObjects /* [out] [length_is(*puReturned),size_is(uCount),ref] */,
 							 uint32_t *_puReturned /* [out] [ref] */);
 NTSTATUS dcerpc_IEnumWbemClassObject_Next_recv(struct tevent_req *req,
 					       TALLOC_CTX *mem_ctx,
@@ -739,7 +739,7 @@ NTSTATUS dcerpc_IEnumWbemClassObject_Next(struct dcerpc_binding_handle *h,
 					  struct ORPCTHIS _ORPCthis /* [in]  */,
 					  int32_t _lTimeout /* [in]  */,
 					  uint32_t _uCount /* [in]  */,
-					  struct MInterfacePointer **_apObjects /* [out] [ref,size_is(uCount),length_is(*puReturned)] */,
+					  struct MInterfacePointer **_apObjects /* [out] [length_is(*puReturned),size_is(uCount),ref] */,
 					  uint32_t *_puReturned /* [out] [ref] */,
 					  WERROR *result);
 
@@ -1020,7 +1020,7 @@ struct tevent_req *dcerpc_EstablishPosition_send(TALLOC_CTX *mem_ctx,
 						 struct dcerpc_binding_handle *h,
 						 struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 						 struct ORPCTHIS _ORPCthis /* [in]  */,
-						 const char *_wszLocaleList /* [in] [charset(UTF16),unique] */,
+						 const char *_wszLocaleList /* [in] [unique,charset(UTF16)] */,
 						 uint32_t _dwNumLocales /* [in]  */,
 						 uint32_t *_reserved /* [out] [ref] */);
 NTSTATUS dcerpc_EstablishPosition_recv(struct tevent_req *req,
@@ -1030,7 +1030,7 @@ NTSTATUS dcerpc_EstablishPosition(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 				  struct ORPCTHIS _ORPCthis /* [in]  */,
-				  const char *_wszLocaleList /* [in] [charset(UTF16),unique] */,
+				  const char *_wszLocaleList /* [in] [unique,charset(UTF16)] */,
 				  uint32_t _dwNumLocales /* [in]  */,
 				  uint32_t *_reserved /* [out] [ref] */,
 				  WERROR *result);
@@ -1046,9 +1046,9 @@ struct tevent_req *dcerpc_RequestChallenge_send(TALLOC_CTX *mem_ctx,
 						struct dcerpc_binding_handle *h,
 						struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 						struct ORPCTHIS _ORPCthis /* [in]  */,
-						const char *_wszNetworkResource /* [in] [unique,charset(UTF16)] */,
+						const char *_wszNetworkResource /* [in] [charset(UTF16),unique] */,
 						const char *_wszUser /* [in] [charset(UTF16),unique] */,
-						uint8_t *_Nonce /* [out] [length_is(16),ref,size_is(16)] */);
+						uint8_t *_Nonce /* [out] [ref,size_is(16),length_is(16)] */);
 NTSTATUS dcerpc_RequestChallenge_recv(struct tevent_req *req,
 				      TALLOC_CTX *mem_ctx,
 				      WERROR *result);
@@ -1056,9 +1056,9 @@ NTSTATUS dcerpc_RequestChallenge(struct dcerpc_binding_handle *h,
 				 TALLOC_CTX *mem_ctx,
 				 struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 				 struct ORPCTHIS _ORPCthis /* [in]  */,
-				 const char *_wszNetworkResource /* [in] [unique,charset(UTF16)] */,
+				 const char *_wszNetworkResource /* [in] [charset(UTF16),unique] */,
 				 const char *_wszUser /* [in] [charset(UTF16),unique] */,
-				 uint8_t *_Nonce /* [out] [length_is(16),ref,size_is(16)] */,
+				 uint8_t *_Nonce /* [out] [ref,size_is(16),length_is(16)] */,
 				 WERROR *result);
 
 struct tevent_req *dcerpc_WBEMLogin_r_send(TALLOC_CTX *mem_ctx,
@@ -1073,7 +1073,7 @@ struct tevent_req *dcerpc_WBEMLogin_send(TALLOC_CTX *mem_ctx,
 					 struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 					 struct ORPCTHIS _ORPCthis /* [in]  */,
 					 const char *_wszPreferredLocale /* [in] [unique,charset(UTF16)] */,
-					 uint8_t *_AccessToken /* [in] [size_is(16),length_is(16),unique] */,
+					 uint8_t *_AccessToken /* [in] [length_is(16),size_is(16),unique] */,
 					 int32_t _lFlags /* [in]  */,
 					 struct MInterfacePointer *_pCtx /* [in] [ref] */,
 					 struct MInterfacePointer **_ppNamespace /* [out] [ref] */);
@@ -1085,7 +1085,7 @@ NTSTATUS dcerpc_WBEMLogin(struct dcerpc_binding_handle *h,
 			  struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 			  struct ORPCTHIS _ORPCthis /* [in]  */,
 			  const char *_wszPreferredLocale /* [in] [unique,charset(UTF16)] */,
-			  uint8_t *_AccessToken /* [in] [size_is(16),length_is(16),unique] */,
+			  uint8_t *_AccessToken /* [in] [length_is(16),size_is(16),unique] */,
 			  int32_t _lFlags /* [in]  */,
 			  struct MInterfacePointer *_pCtx /* [in] [ref] */,
 			  struct MInterfacePointer **_ppNamespace /* [out] [ref] */,
@@ -1102,7 +1102,7 @@ struct tevent_req *dcerpc_NTLMLogin_send(TALLOC_CTX *mem_ctx,
 					 struct dcerpc_binding_handle *h,
 					 struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 					 struct ORPCTHIS _ORPCthis /* [in]  */,
-					 const char *_wszNetworkResource /* [in] [charset(UTF16),unique] */,
+					 const char *_wszNetworkResource /* [in] [unique,charset(UTF16)] */,
 					 const char *_wszPreferredLocale /* [in] [charset(UTF16),unique] */,
 					 int32_t _lFlags /* [in]  */,
 					 struct MInterfacePointer *_pCtx /* [in] [unique] */,
@@ -1114,7 +1114,7 @@ NTSTATUS dcerpc_NTLMLogin(struct dcerpc_binding_handle *h,
 			  TALLOC_CTX *mem_ctx,
 			  struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 			  struct ORPCTHIS _ORPCthis /* [in]  */,
-			  const char *_wszNetworkResource /* [in] [charset(UTF16),unique] */,
+			  const char *_wszNetworkResource /* [in] [unique,charset(UTF16)] */,
 			  const char *_wszPreferredLocale /* [in] [charset(UTF16),unique] */,
 			  int32_t _lFlags /* [in]  */,
 			  struct MInterfacePointer *_pCtx /* [in] [unique] */,
@@ -1145,7 +1145,7 @@ struct tevent_req *dcerpc_IWbemWCOSmartEnum_Next_send(TALLOC_CTX *mem_ctx,
 						      struct GUID *_gWCO /* [in] [ref] */,
 						      uint32_t *_puReturned /* [out] [ref] */,
 						      uint32_t *_pSize /* [out] [ref] */,
-						      uint8_t **_pData /* [out] [size_is(,*pSize),ref] */);
+						      uint8_t **_pData /* [out] [ref,size_is(,*pSize)] */);
 NTSTATUS dcerpc_IWbemWCOSmartEnum_Next_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    WERROR *result);
@@ -1160,7 +1160,7 @@ NTSTATUS dcerpc_IWbemWCOSmartEnum_Next(struct dcerpc_binding_handle *h,
 				       struct GUID *_gWCO /* [in] [ref] */,
 				       uint32_t *_puReturned /* [out] [ref] */,
 				       uint32_t *_pSize /* [out] [ref] */,
-				       uint8_t **_pData /* [out] [size_is(,*pSize),ref] */,
+				       uint8_t **_pData /* [out] [ref,size_is(,*pSize)] */,
 				       WERROR *result);
 
 #endif /* _HEADER_RPC_IWbemWCOSmartEnum */
